

library(dplyr)
library(tidyr)
library(sf)
library(picante)
library(raster)
library(ape)
library(FD)


rm(list = ls())





# ----------------------- USER-DEFINED PARAMETERS ----------------------------------------------------------------
# Load functions
source("0_FunctionalDiversity190528_funs.R")
st_erase = function(x, y) st_difference(x, st_union(st_combine(y)))

# Desired patial projection
prj <- "+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs"
	
# Number of randomization iterations to calculate bias in funct & phylogen loss
numrands <- 500  

# Bonferroni-correction
Ntot <- 232 # number of coutries for which we calculate FD and PD (i.e. where SR.0 > 1)
bc <- (0.05 / Ntot) / 2  # two-tailed; family-wise alpha = 0.05




#----------------------- SPECIES DATA -------------------------------------------------
#--- Species traits & threats
dat1 <- data.frame(read.csv("Data/Raw/mammal_threats_traits.csv", header=T))
dat1$species <- as.character(dat1$species)
dat1$species.phylog <- as.character(dat1$species.phylog)
dat1$ExceptionsToDecline[dat1$ExceptionsToDecline == "na"] <- NA


#--- Phylogenetic tree
#spptree <- read.tree("Data/Raw/mammaltree.tree") # Uyeda et al. tree

# Randomly select one of the 10,000 trees from Upham et al. (PLoS 2019)
#x1 <- round(runif(n = 1, min = 1, max = length(list.files("Data/Completed_5911sp_topoCons_NDexp"))), 0)
#randtree <- list.files("Data/Completed_5911sp_topoCons_NDexp")[x1]
#spptree <- read.tree(paste("Data/Completed_5911sp_topoCons_NDexp/", randtree, sep = ""))

# Randomly select T trees from Upham et al. (PLoS 2019)
#x1 <- round(runif(n = T, min = 1, max = length(list.files("Data/Completed_5911sp_topoCons_NDexp"))), 0)
#randtrees <- list.files("Data/Completed_5911sp_topoCons_NDexp")[x1]

# Select a "mean" phylogeny from Upham
spptree <- read.tree("Data/Upham_mean_phylogeny_ultrametric.tree")





#----------------------- COUNTRIES AND SPP RANGE PREP ---------------------------------
ctrs <- st_read("Data/Raw/UIA_World_Countries_Boundaries.shp") %>%
	dplyr::select(Country, geometry) %>%
	st_transform(st_crs(prj)) %>%
	mutate(ctry_sq_km = as.numeric(st_area(.))/1000000)  
ctrs_area <- ctrs %>%
	as.data.frame() %>%
	dplyr::select(Country, ctry_sq_km, - geometry) 
ctrs_df <- ctrs %>%	
	as.data.frame() %>%
	dplyr::select(-geometry) 
ctrs_df$Country <- as.character(ctrs_df$Country)

# Run functions to prepare range polygons
# removes mammals who are listed as extinct
############ DATA BELOW DOWNLOADED FROM IUCN RED LIST ############################
mam <- prep_range_polys(fn = "Data/Raw/TERRESTRIAL_MAMMALS.shp", ctrs = ctrs)





#----------------------- SPECIES - COUNTRY INTERSECTIONS ---------------------------------
polys_ctrs_int <- st_intersects(mam, ctrs, sparse = FALSE) 
# Dimensions: nrow = number of spp (12112 for mammals), ncol = number of countries (254)

spp_int_ls <- list()
for(i in 1:nrow(ctrs_df)){
	polys_ctrs_int_vec <- which(polys_ctrs_int[,i] == TRUE)
	spp_list_ctr <- mam[polys_ctrs_int_vec, 1]
	st_geometry(spp_list_ctr) <- NULL
	spp_int_ls[[i]] <- spp_list_ctr	}

	



#----------------------- MANUALLY ADD CERTAIN SPECIES ---------------------------------
# Species present in IUCN range descriptions but not IUCN range maps
# Maldives
add <- data.frame(species = "Myotis_blythii")
spp_int_ls[[59]] <- rbind(spp_int_ls[[59]], add)
# Turkey
add <- data.frame(species = "Miniopterus_schreibersii")
spp_int_ls[[16]] <- rbind(spp_int_ls[[16]], add)
# France
add <- data.frame(species = "Speothos_venaticus")
spp_int_ls[[34]] <- rbind(spp_int_ls[[34]], add)
# Sri Lanka
add <- data.frame(species = "Myotis_blythii")
spp_int_ls[[63]] <- rbind(spp_int_ls[[63]], add)
# Bangladesh
add <- data.frame(species = "Myotis_blythii")
spp_int_ls[[80]] <- rbind(spp_int_ls[[80]], add)
# Bhutan
add <- data.frame(species = "Myotis_blythii")
spp_int_ls[[81]] <- rbind(spp_int_ls[[81]], add)
# Israel
add <- data.frame(species = "Gazella_dorcas")
spp_int_ls[[224]] <- rbind(spp_int_ls[[224]], add)
# Croatia
add <- data.frame(species = "Miniopterus_schreibersii")
spp_int_ls[[248]] <- rbind(spp_int_ls[[248]], add)
# Bulgaria
add <- data.frame(species = "Miniopterus_schreibersii")
spp_int_ls[[254]] <- rbind(spp_int_ls[[254]], add)



#----------------------- EXCEPTIONS TO DECLINE ---------------------------------
exc_tmp <- dat1 %>%
	dplyr::select(species, ExceptionsToDecline)
exc_tmp$ExceptionsToDecline <- as.character(exc_tmp$ExceptionsToDecline)

#  Do first one to start data frame
spp <- exc_tmp$species[1]
tmp <- exc_tmp$ExceptionsToDecline[1]
tmp_df <- as.data.frame(tmp) %>%
	tidyr::separate(tmp, paste("Country", 1:22, sep="_"), sep = ", ") 
exc_df <- cbind(spp, tmp_df)

for(i in 1:nrow(exc_tmp)){
	spp <- exc_tmp$species[i]
	tmp <- exc_tmp$ExceptionsToDecline[i]
	tmp_df <- as.data.frame(tmp) %>%
		tidyr::separate(tmp, paste("Country", 1:22, sep="_"), sep = ", ") 
	new_row <- cbind(spp, tmp_df)
	exc_df <- rbind(exc_df, new_row)	}
	
exc_df <- exc_df[rowSums(is.na(exc_df[,2:23])) != 22,]
exc_df <- exc_df %>%
	mutate_if(is.factor, as.character)

dat1 <- subset(dat1, select = -c(ExceptionsToDecline))



#----------------------- Number of countries to analyze ---------------------------------------
numcountries <- length(spp_int_ls)

	


#----------------------- SAVE DATA FOR LATER USE / LOAD PREVIOUSLY PREPPED DATA ----------------
#save.image("Data/working")
#load("Data/working")




#----------------------- ASSESS THREATS PER COUNTRY ------------------------------
### 'FOR' LOOP, RUNNING THROUGH EACH COUNTRY ONE BY ONE



outmat <- data.frame(matrix(nrow = numcountries, ncol = 170))
names(outmat) <- c("SR.0", "SR.allthreats", "SR.habitat", "SR.hunting", "SR.climate", "SR.conflict", 
	"SR.nonnat", "SR.pollution", "SR.hybrid", "SR.prey", "SR.disease", "SR.inbreeding", 
	"FD.0", "FD.allthreats", "FD.habitat", "FD.hunting", "FD.climate", "FD.conflict", 
	"FD.nonnat", "FD.pollution", "FD.hybrid", "FD.prey", "FD.disease", "FD.inbreeding", 
 	"FDrand.allthreats", "FDrand.habitat", "FDrand.hunting", "FDrand.climate", "FDrand.conflict", 
	"FDrand.nonnat", "FDrand.pollution", "FDrand.hybrid", "FDrand.prey", "FDrand.disease", "FDrand.inbreeding", 
	"FDrandLO.allthreats", "FDrandLO.habitat", "FDrandLO.hunting", "FDrandLO.climate", "FDrandLO.conflict", 
	"FDrandLO.nonnat", "FDrandLO.pollution", "FDrandLO.hybrid", "FDrandLO.prey", "FDrandLO.disease", "FDrandLO.inbreeding", 
	"FDrandHI.allthreats", "FDrandHI.habitat", "FDrandHI.hunting", "FDrandHI.climate", "FDrandHI.conflict", 
	"FDrandHI.nonnat", "FDrandHI.pollution", "FDrandHI.hybrid", "FDrandHI.prey", "FDrandHI.disease", "FDrandHI.inbreeding", 
	"FDrandLObonferroni.allthreats", "FDrandLObonferroni.habitat", "FDrandLObonferroni.hunting", "FDrandLObonferroni.climate", "FDrandLObonferroni.conflict", 
	"FDrandLObonferroni.nonnat", "FDrandLObonferroni.pollution", "FDrandLObonferroni.hybrid", "FDrandLObonferroni.prey", "FDrandLObonferroni.disease", "FDrandLObonferroni.inbreeding", 
	"FDrandHIbonferroni.allthreats", "FDrandHIbonferroni.habitat", "FDrandHIbonferroni.hunting", "FDrandHIbonferroni.climate", "FDrandHIbonferroni.conflict", 
	"FDrandHIbonferroni.nonnat", "FDrandHIbonferroni.pollution", "FDrandHIbonferroni.hybrid", "FDrandHIbonferroni.prey", "FDrandHIbonferroni.disease", "FDrandHIbonferroni.inbreeding", 
	"PD.0", "PD.allthreats", "PD.habitat", "PD.hunting", "PD.climate", "PD.conflict", 
	"PD.nonnat", "PD.pollution", "PD.hybrid", "PD.prey", "PD.disease", "PD.inbreeding", 
	"PDrand.allthreats", "PDrand.habitat", "PDrand.hunting", "PDrand.climate", "PDrand.conflict", 
	"PDrand.nonnat", "PDrand.pollution", "PDrand.hybrid", "PDrand.prey", "PDrand.disease", "PDrand.inbreeding", 
	"PDrandLO.allthreats", "PDrandLO.habitat", "PDrandLO.hunting", "PDrandLO.climate", "PDrandLO.conflict", 
	"PDrandLO.nonnat", "PDrandLO.pollution", "PDrandLO.hybrid", "PDrandLO.prey", "PDrandLO.disease", "PDrandLO.inbreeding", 
	"PDrandHI.allthreats", "PDrandHI.habitat", "PDrandHI.hunting", "PDrandHI.climate", "PDrandHI.conflict", 
	"PDrandHI.nonnat", "PDrandHI.pollution", "PDrandHI.hybrid", "PDrandHI.prey", "PDrandHI.disease", "PDrandHI.inbreeding", 
	"PDrandLObonferroni.allthreats", "PDrandLObonferroni.habitat", "PDrandLObonferroni.hunting", "PDrandLObonferroni.climate", "PDrandLObonferroni.conflict", 
	"PDrandLObonferroni.nonnat", "PDrandLObonferroni.pollution", "PDrandLObonferroni.hybrid", "PDrandLObonferroni.prey", "PDrandLObonferroni.disease", "PDrandLObonferroni.inbreeding", 
	"PDrandHIbonferroni.allthreats", "PDrandHIbonferroni.habitat", "PDrandHIbonferroni.hunting", "PDrandHIbonferroni.climate", "PDrandHIbonferroni.conflict", 
	"PDrandHIbonferroni.nonnat", "PDrandHIbonferroni.pollution", "PDrandHIbonferroni.hybrid", "PDrandHIbonferroni.prey", "PDrandHIbonferroni.disease", "PDrandHIbonferroni.inbreeding", 
	"TraitChange.hab.DietInv", "TraitChange.hab.DietVert", "TraitChange.hab.DietFish", "TraitChange.hab.DietScav", 
	"TraitChange.hab.DietFruit", "TraitChange.hab.DietNect", "TraitChange.hab.DietSeed", "TraitChange.hab.DietHerb", 
	"TraitChange.hab.BodyMass", "TraitChange.hab.Ground", "TraitChange.hab.Climbing", "TraitChange.hab.Volant", 
	"TraitChange.hunt.DietInv", "TraitChange.hunt.DietVert", "TraitChange.hunt.DietFish", "TraitChange.hunt.DietScav", 
	"TraitChange.hunt.DietFruit", "TraitChange.hunt.DietNect", "TraitChange.hunt.DietSeed", "TraitChange.hunt.DietHerb", 
	"TraitChange.hunt.BodyMass", "TraitChange.hunt.Ground", "TraitChange.hunt.Climbing", "TraitChange.hunt.Volant"	)
	


start <- Sys.time()
start

for(i in 1:numcountries){ 
#tryCatch({

	#i=7

	# Exceptions to decline for country i
	country_name <- as.character(ctrs_df[i,1])
	keep_exc <- which(apply(exc_df, 1, function(r) any(r %in% country_name)))
	spp_exc <- exc_df[keep_exc,1]
	spp_exc_df <- as.data.frame(spp_exc)
	colnames(spp_exc_df) <- "species"
	
	# Species list in country i
	spp_list <- spp_int_ls[[i]]
	spp_list <- unique(spp_list) 

	datXY <- dplyr::left_join(spp_list, dat1, by="species") 
	datXY <- datXY[complete.cases(datXY),]
	SR.0 <- nrow(datXY) # Taxonomic diversity (species richness)
	t0.01 <- mean(datXY$DietInv)
	t0.02 <- mean(datXY$DietVert)
	t0.03 <- mean(datXY$DietFish)
	t0.04 <- mean(datXY$DietScav)
	t0.05 <- mean(datXY$DietFruit)
	t0.06 <- mean(datXY$DietNect)
	t0.07 <- mean(datXY$DietSeed)
	t0.08 <- mean(datXY$DietHerb)
	t0.09 <- mean(datXY$BodyMass)
	t0.10 <- mean(datXY$Ground)
	t0.11 <- mean(datXY$Climbing)
	t0.12 <- mean(datXY$Volant)



	#----- Current (standing) diversity
 	# Functional diversity of all species in country i
	speciestraitsXY <- cbind.data.frame(species.phylog=datXY$species.phylog, DietInv=datXY$DietInv, 
		DietVert=datXY$DietVert, DietFish=datXY$DietFish, 
		DietScav=datXY$DietScav, DietFruit=datXY$DietFruit, DietNect=datXY$DietNect, 
		DietSeed=datXY$DietSeed, DietHerb=datXY$DietHerb, BodyMass=datXY$BodyMass, 
		Ground=datXY$Ground, Climbing=datXY$Climbing, Volant=datXY$Volant)
	row.names(speciestraitsXY) <- datXY$species
	speciestraitsXY.fd <- subset(speciestraitsXY, select = -c(species.phylog))
	#fdcalc <- FD::dbFD(speciestraitsXY.fd, m = "min", corr = "cailliez", messages = F)
	#fdcalc <- FD::dbFD(speciestraitsXY.fd, calc.FRic = F, messages = F)
	fdcalc <- FD::dbFD(speciestraitsXY.fd, m = 4)
	FD.0 <- ifelse(SR.0 > 2, as.numeric(fdcalc$FRic), NA)

	# Phylogenetic diversity
	phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(datXY)))
	names(phymat) <- datXY$species.phylog
	PD.0 <- ifelse(SR.0 > 2, picante::pd(phymat, spptree, include.root = TRUE)$PD, NA)



	#----- Spp impacts: All threats
	# Removing species undergoing population decline
	remaining_spp <- subset(datXY, trend != "Decreasing")
	SR.remaining <- nrow(remaining_spp)
	SR.allthreats <- SR.remaining
	numspploss.allthreats <- SR.0 - nrow(remaining_spp)
	speciestraits <- cbind.data.frame(species.phylog= remaining_spp$species.phylog,
		DietInv= remaining_spp$DietInv, 
	      DietVert= remaining_spp$DietVert, DietFish= remaining_spp$DietFish, 
	   	DietScav= remaining_spp$DietScav, DietFruit= remaining_spp$DietFruit, 
	   	DietNect= remaining_spp$DietNect, DietSeed= remaining_spp$DietSeed, 
	   	DietHerb= remaining_spp$DietHerb, BodyMass= remaining_spp$BodyMass, 
	   	Ground= remaining_spp$Ground, Climbing= remaining_spp$Climbing, 
	   	Volant= remaining_spp$Volant)
	row.names(speciestraits) <- remaining_spp$species
		
	# PD
	if(SR.remaining == 0){PD.allthreats <- 0} else 
	if(SR.remaining == SR.0){PD.allthreats <- 1} else {
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(remaining_spp)))
		names(phymat) <- speciestraits$species.phylog
		PD.allthreats <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0		}

	# FD			
	if(SR.remaining < 2){FD.allthreats <- NA; FDrand.allthreats <- NA; FDrandLO.allthreats <- NA; FDrandHI.allthreats <- NA; 
	  	FDrandLObonferroni.allthreats <- NA; FDrandHIbonferroni.allthreats <- NA; PDrand.allthreats <- NA;
	  	PDrandLO.allthreats <- NA; PDrandHI.allthreats <- NA; 
	  	PDrandLObonferroni.allthreats <- NA; PDrandHIbonferroni.allthreats <- NA} else
	 
	if(SR.remaining == SR.0){FD.allthreats <- 1; FDrand.allthreats <- 1; FDrandLO.allthreats <- 1; FDrandHI.allthreats <- 1; 
	  	FDrandLObonferroni.allthreats <- 1; FDrandHIbonferroni.allthreats <- 1; PDrand.allthreats <- 1;
	  	PDrandLO.allthreats <- 1; PDrandHI.allthreats <- 1; 
	  	PDrandLObonferroni.allthreats <- 1; PDrandHIbonferroni.allthreats <- 1} else {	
		
	speciestraits.fd <- subset(speciestraits, select = -c(species.phylog))
	fdcalc <- FD::dbFD(speciestraits.fd, m = 4)
	FD.allthreats <- as.numeric(fdcalc$FRic) / FD.0

	FD.r <- vector(length = numrands)
	PD.r <- vector(length = numrands)
	for(r in 1:numrands){	
	   tryCatch({
		#r=1
		spp.r <- speciestraitsXY[sample(nrow(speciestraitsXY), size = SR.remaining, replace = F),]
		spp.r.fd <- subset(spp.r, select = -c(species.phylog))	
		fdcalc <- FD::dbFD(spp.r.fd, m = 4)
		FD.r[r] <- as.numeric(fdcalc$FRic) / FD.0
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(spp.r)))
		names(phymat) <- spp.r$species.phylog 
		PD.r[r] <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0	
		rm("spp.r", "spp.r.fd", "fdcalc", "phymat")
	   }, error=function(e){}) # end of the tryCatch function
	} # end r loop
	FDrand.allthreats <- mean(FD.r, na.rm=T) 
	FDrandLO.allthreats <- quantile(FD.r, probs=c(0.025), na.rm=T)
	FDrandHI.allthreats <- quantile(FD.r, probs=c(0.975), na.rm=T)
	FDrandLObonferroni.allthreats <- quantile(FD.r, probs=c(bc), na.rm=T)
	FDrandHIbonferroni.allthreats <- quantile(FD.r, probs=c(1-bc), na.rm=T)
	PDrand.allthreats <- mean(PD.r, na.rm=T); 
	PDrandLO.allthreats <- quantile(PD.r, probs=c(0.025), na.rm=T) 
	PDrandHI.allthreats <- quantile(PD.r, probs=c(0.975), na.rm=T)
	PDrandLObonferroni.allthreats <- quantile(PD.r, probs=c(bc), na.rm=T) 
	PDrandHIbonferroni.allthreats <- quantile(PD.r, probs=c(1-bc), na.rm=T) 
	rm(FD.r, PD.r)
	}  # end if loop
	rm(remaining_spp, SR.remaining, speciestraits)
		



		
	#----- Spp impacts: Habitat loss
	# Removing species where the threat is major (1) and causing population decline
	remaining_spp <- datXY
	remaining_spp$cond <- ifelse(remaining_spp$trend == "Decreasing" & remaining_spp$habitat == 1, 1, 0)
	remaining_spp <- subset(remaining_spp, cond != 1)
	SR.remaining <- nrow(remaining_spp)
	SR.habitat <- SR.remaining
	numspploss.habitat <- SR.0 - nrow(remaining_spp)
	speciestraits <- cbind.data.frame(species.phylog= remaining_spp$species.phylog,
		DietInv= remaining_spp$DietInv, 
	      DietVert= remaining_spp$DietVert, DietFish= remaining_spp$DietFish, 
	   	DietScav= remaining_spp$DietScav, DietFruit= remaining_spp$DietFruit, 
	   	DietNect= remaining_spp$DietNect, DietSeed= remaining_spp$DietSeed, 
	   	DietHerb= remaining_spp$DietHerb, BodyMass= remaining_spp$BodyMass, 
	   	Ground= remaining_spp$Ground, Climbing= remaining_spp$Climbing, 
	   	Volant= remaining_spp$Volant)
	row.names(speciestraits) <- remaining_spp$species
	thab.01 <- mean(speciestraits$DietInv)
	thab.02 <- mean(speciestraits$DietVert)
	thab.03 <- mean(speciestraits$DietFish)
	thab.04 <- mean(speciestraits$DietScav)
	thab.05 <- mean(speciestraits$DietFruit)
	thab.06 <- mean(speciestraits$DietNect)
	thab.07 <- mean(speciestraits$DietSeed)
	thab.08 <- mean(speciestraits$DietHerb)
	thab.09 <- mean(speciestraits$BodyMass)
	thab.10 <- mean(speciestraits$Ground)
	thab.11 <- mean(speciestraits$Climbing)
	thab.12 <- mean(speciestraits$Volant)
	
	# PD
	if(SR.remaining == 0){PD.habitat <- 0} else 
	if(SR.remaining == SR.0){PD.habitat <- 1} else {
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(remaining_spp)))
		names(phymat) <- speciestraits$species.phylog
		PD.habitat <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0		}

	# FD			
	if(SR.remaining < 2){FD.habitat <- NA; FDrand.habitat <- NA; FDrandLO.habitat <- NA; FDrandHI.habitat <- NA; 
	  	FDrandLObonferroni.habitat <- NA; FDrandHIbonferroni.habitat <- NA; PDrand.habitat <- NA;
	  	PDrandLO.habitat <- NA; PDrandHI.habitat <- NA; 
	  	PDrandLObonferroni.habitat <- NA; PDrandHIbonferroni.habitat <- NA} else
	 
	if(SR.remaining == SR.0){FD.habitat <- 1; FDrand.habitat <- 1; FDrandLO.habitat <- 1; FDrandHI.habitat <- 1; 
	  	FDrandLObonferroni.habitat <- 1; FDrandHIbonferroni.habitat <- 1; PDrand.habitat <- 1;
	  	PDrandLO.habitat <- 1; PDrandHI.habitat <- 1; 
	  	PDrandLObonferroni.habitat <- 1; PDrandHIbonferroni.habitat <- 1} else {	
		
	speciestraits.fd <- subset(speciestraits, select = -c(species.phylog))
	fdcalc <- FD::dbFD(speciestraits.fd, m = 4)
	FD.habitat <- as.numeric(fdcalc$FRic) / FD.0

	FD.r <- vector(length = numrands)
	PD.r <- vector(length = numrands)
	for(r in 1:numrands){	
	   tryCatch({
		#r=1
		spp.r <- speciestraitsXY[sample(nrow(speciestraitsXY), size = SR.remaining, replace = F),]
		spp.r.fd <- subset(spp.r, select = -c(species.phylog))	
		fdcalc <- FD::dbFD(spp.r.fd, m = 4)
		FD.r[r] <- as.numeric(fdcalc$FRic) / FD.0
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(spp.r)))
		names(phymat) <- spp.r$species.phylog 
		PD.r[r] <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0	
		rm("spp.r", "spp.r.fd", "fdcalc", "phymat")
	   }, error=function(e){}) # end of the tryCatch function
	} # end r loop
	FDrand.habitat <- mean(FD.r, na.rm=T) 
	FDrandLO.habitat <- quantile(FD.r, probs=c(0.025), na.rm=T)
	FDrandHI.habitat <- quantile(FD.r, probs=c(0.975), na.rm=T)
	FDrandLObonferroni.habitat <- quantile(FD.r, probs=c(bc), na.rm=T)
	FDrandHIbonferroni.habitat <- quantile(FD.r, probs=c(1-bc), na.rm=T)
	PDrand.habitat <- mean(PD.r, na.rm=T); 
	PDrandLO.habitat <- quantile(PD.r, probs=c(0.025), na.rm=T) 
	PDrandHI.habitat <- quantile(PD.r, probs=c(0.975), na.rm=T)
	PDrandLObonferroni.habitat <- quantile(PD.r, probs=c(bc), na.rm=T) 
	PDrandHIbonferroni.habitat <- quantile(PD.r, probs=c(1-bc), na.rm=T) 
	rm(FD.r, PD.r)
	}  # end if loop
	rm(remaining_spp, SR.remaining, speciestraits)
		


		
		
	#----- Spp impacts: Hunting
	# Removing species where the threat is major (1) and causing population decline
	remaining_spp <- datXY
	remaining_spp$cond <- ifelse(remaining_spp$trend == "Decreasing" & remaining_spp$hunting == 1, 1, 0)
	remaining_spp <- subset(remaining_spp, cond != 1)
	SR.remaining <- nrow(remaining_spp)
	SR.hunting <- SR.remaining
	numspploss.hunting <- SR.0 - nrow(remaining_spp)
	speciestraits <- cbind.data.frame(species.phylog= remaining_spp$species.phylog,
		DietInv= remaining_spp$DietInv, 
	      DietVert= remaining_spp$DietVert, DietFish= remaining_spp$DietFish, 
	   	DietScav= remaining_spp$DietScav, DietFruit= remaining_spp$DietFruit, 
	   	DietNect= remaining_spp$DietNect, DietSeed= remaining_spp$DietSeed, 
	   	DietHerb= remaining_spp$DietHerb, BodyMass= remaining_spp$BodyMass, 
	   	Ground= remaining_spp$Ground, Climbing= remaining_spp$Climbing, 
	   	Volant= remaining_spp$Volant)
	row.names(speciestraits) <- remaining_spp$species
	thunt.01 <- mean(speciestraits$DietInv)
	thunt.02 <- mean(speciestraits$DietVert)
	thunt.03 <- mean(speciestraits$DietFish)
	thunt.04 <- mean(speciestraits$DietScav)
	thunt.05 <- mean(speciestraits$DietFruit)
	thunt.06 <- mean(speciestraits$DietNect)
	thunt.07 <- mean(speciestraits$DietSeed)
	thunt.08 <- mean(speciestraits$DietHerb)
	thunt.09 <- mean(speciestraits$BodyMass)
	thunt.10 <- mean(speciestraits$Ground)
	thunt.11 <- mean(speciestraits$Climbing)
	thunt.12 <- mean(speciestraits$Volant)
		
	# PD
	if(SR.remaining == 0){PD.hunting <- 0} else 
	if(SR.remaining == SR.0){PD.hunting <- 1} else {
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(remaining_spp)))
		names(phymat) <- speciestraits$species.phylog
		PD.hunting <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0		}

	# FD			
	if(SR.remaining < 2){FD.hunting <- NA; FDrand.hunting <- NA; FDrandLO.hunting <- NA; FDrandHI.hunting <- NA; 
	  	FDrandLObonferroni.hunting <- NA; FDrandHIbonferroni.hunting <- NA; PDrand.hunting <- NA;
	  	PDrandLO.hunting <- NA; PDrandHI.hunting <- NA; 
	  	PDrandLObonferroni.hunting <- NA; PDrandHIbonferroni.hunting <- NA} else
	 
	if(SR.remaining == SR.0){FD.hunting <- 1; FDrand.hunting <- 1; FDrandLO.hunting <- 1; FDrandHI.hunting <- 1; 
	  	FDrandLObonferroni.hunting <- 1; FDrandHIbonferroni.hunting <- 1; PDrand.hunting <- 1;
	  	PDrandLO.hunting <- 1; PDrandHI.hunting <- 1; 
	  	PDrandLObonferroni.hunting <- 1; PDrandHIbonferroni.hunting <- 1} else {	
		
	speciestraits.fd <- subset(speciestraits, select = -c(species.phylog))
	fdcalc <- FD::dbFD(speciestraits.fd, m = 4)
	FD.hunting <- as.numeric(fdcalc$FRic) / FD.0

	FD.r <- vector(length = numrands)
	PD.r <- vector(length = numrands)
	for(r in 1:numrands){	
	   tryCatch({
		#r=1
		spp.r <- speciestraitsXY[sample(nrow(speciestraitsXY), size = SR.remaining, replace = F),]
		spp.r.fd <- subset(spp.r, select = -c(species.phylog))	
		fdcalc <- FD::dbFD(spp.r.fd, m = 4)
		FD.r[r] <- as.numeric(fdcalc$FRic) / FD.0
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(spp.r)))
		names(phymat) <- spp.r$species.phylog 
		PD.r[r] <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0	
		rm("spp.r", "spp.r.fd", "fdcalc", "phymat")
	   }, error=function(e){}) # end of the tryCatch function
	} # end r loop
	FDrand.hunting <- mean(FD.r, na.rm=T) 
	FDrandLO.hunting <- quantile(FD.r, probs=c(0.025), na.rm=T)
	FDrandHI.hunting <- quantile(FD.r, probs=c(0.975), na.rm=T)
	FDrandLObonferroni.hunting <- quantile(FD.r, probs=c(bc), na.rm=T)
	FDrandHIbonferroni.hunting <- quantile(FD.r, probs=c(1-bc), na.rm=T)
	PDrand.hunting <- mean(PD.r, na.rm=T); 
	PDrandLO.hunting <- quantile(PD.r, probs=c(0.025), na.rm=T) 
	PDrandHI.hunting <- quantile(PD.r, probs=c(0.975), na.rm=T)
	PDrandLObonferroni.hunting <- quantile(PD.r, probs=c(bc), na.rm=T) 
	PDrandHIbonferroni.hunting <- quantile(PD.r, probs=c(1-bc), na.rm=T) 
	rm(FD.r, PD.r)
	}  # end if loop
	rm(remaining_spp, SR.remaining, speciestraits)
		


		
		
	
	#----- Spp impacts: Climate change
	# Removing species where the threat is major (1) and causing population decline
	remaining_spp <- datXY
	remaining_spp$cond <- ifelse(remaining_spp$trend == "Decreasing" & remaining_spp$climate == 1, 1, 0)
	remaining_spp <- subset(remaining_spp, cond != 1)
	SR.remaining <- nrow(remaining_spp)
	SR.climate <- SR.remaining
	numspploss.climate <- SR.0 - nrow(remaining_spp)
	speciestraits <- cbind.data.frame(species.phylog= remaining_spp$species.phylog,
		DietInv= remaining_spp$DietInv, 
	      DietVert= remaining_spp$DietVert, DietFish= remaining_spp$DietFish, 
	   	DietScav= remaining_spp$DietScav, DietFruit= remaining_spp$DietFruit, 
	   	DietNect= remaining_spp$DietNect, DietSeed= remaining_spp$DietSeed, 
	   	DietHerb= remaining_spp$DietHerb, BodyMass= remaining_spp$BodyMass, 
	   	Ground= remaining_spp$Ground, Climbing= remaining_spp$Climbing, 
	   	Volant= remaining_spp$Volant)
	row.names(speciestraits) <- remaining_spp$species
		
	# PD
	if(SR.remaining == 0){PD.climate <- 0} else 
	if(SR.remaining == SR.0){PD.climate <- 1} else {
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(remaining_spp)))
		names(phymat) <- speciestraits$species.phylog
		PD.climate <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0		}

	# FD			
	if(SR.remaining < 2){FD.climate <- NA; FDrand.climate <- NA; FDrandLO.climate <- NA; FDrandHI.climate <- NA; 
	  	FDrandLObonferroni.climate <- NA; FDrandHIbonferroni.climate <- NA; PDrand.climate <- NA;
	  	PDrandLO.climate <- NA; PDrandHI.climate <- NA; 
	  	PDrandLObonferroni.climate <- NA; PDrandHIbonferroni.climate <- NA} else
	 
	if(SR.remaining == SR.0){FD.climate <- 1; FDrand.climate <- 1; FDrandLO.climate <- 1; FDrandHI.climate <- 1; 
	  	FDrandLObonferroni.climate <- 1; FDrandHIbonferroni.climate <- 1; PDrand.climate <- 1;
	  	PDrandLO.climate <- 1; PDrandHI.climate <- 1; 
	  	PDrandLObonferroni.climate <- 1; PDrandHIbonferroni.climate <- 1} else {	
		
	speciestraits.fd <- subset(speciestraits, select = -c(species.phylog))
	fdcalc <- FD::dbFD(speciestraits.fd, m = 4)
	FD.climate <- as.numeric(fdcalc$FRic) / FD.0

	FD.r <- vector(length = numrands)
	PD.r <- vector(length = numrands)
	for(r in 1:numrands){	
	   tryCatch({
		#r=1
		spp.r <- speciestraitsXY[sample(nrow(speciestraitsXY), size = SR.remaining, replace = F),]
		spp.r.fd <- subset(spp.r, select = -c(species.phylog))	
		fdcalc <- FD::dbFD(spp.r.fd, m = 4)
		FD.r[r] <- as.numeric(fdcalc$FRic) / FD.0
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(spp.r)))
		names(phymat) <- spp.r$species.phylog 
		PD.r[r] <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0	
		rm("spp.r", "spp.r.fd", "fdcalc", "phymat")
	   }, error=function(e){}) # end of the tryCatch function
	} # end r loop
	FDrand.climate <- mean(FD.r, na.rm=T) 
	FDrandLO.climate <- quantile(FD.r, probs=c(0.025), na.rm=T)
	FDrandHI.climate <- quantile(FD.r, probs=c(0.975), na.rm=T)
	FDrandLObonferroni.climate <- quantile(FD.r, probs=c(bc), na.rm=T)
	FDrandHIbonferroni.climate <- quantile(FD.r, probs=c(1-bc), na.rm=T)
	PDrand.climate <- mean(PD.r, na.rm=T); 
	PDrandLO.climate <- quantile(PD.r, probs=c(0.025), na.rm=T) 
	PDrandHI.climate <- quantile(PD.r, probs=c(0.975), na.rm=T)
	PDrandLObonferroni.climate <- quantile(PD.r, probs=c(bc), na.rm=T) 
	PDrandHIbonferroni.climate <- quantile(PD.r, probs=c(1-bc), na.rm=T) 
	rm(FD.r, PD.r)
	}  # end if loop
	rm(remaining_spp, SR.remaining, speciestraits)
		


		
		
	#----- Spp impacts: Human-wildlife conflict
	# Removing species where the threat is major (1) and causing population decline
	remaining_spp <- datXY
	remaining_spp$cond <- ifelse(remaining_spp$trend == "Decreasing" & remaining_spp$conflict == 1, 1, 0)
	remaining_spp <- subset(remaining_spp, cond != 1)
	SR.remaining <- nrow(remaining_spp)
	SR.conflict <- SR.remaining
	numspploss.conflict <- SR.0 - nrow(remaining_spp)
	speciestraits <- cbind.data.frame(species.phylog= remaining_spp$species.phylog,
		DietInv= remaining_spp$DietInv, 
	      DietVert= remaining_spp$DietVert, DietFish= remaining_spp$DietFish, 
	   	DietScav= remaining_spp$DietScav, DietFruit= remaining_spp$DietFruit, 
	   	DietNect= remaining_spp$DietNect, DietSeed= remaining_spp$DietSeed, 
	   	DietHerb= remaining_spp$DietHerb, BodyMass= remaining_spp$BodyMass, 
	   	Ground= remaining_spp$Ground, Climbing= remaining_spp$Climbing, 
	   	Volant= remaining_spp$Volant)
	row.names(speciestraits) <- remaining_spp$species
		
	# PD
	if(SR.remaining == 0){PD.conflict <- 0} else 
	if(SR.remaining == SR.0){PD.conflict <- 1} else {
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(remaining_spp)))
		names(phymat) <- speciestraits$species.phylog
		PD.conflict <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0		}

	# FD			
	if(SR.remaining < 2){FD.conflict <- NA; FDrand.conflict <- NA; FDrandLO.conflict <- NA; FDrandHI.conflict <- NA; 
	  	FDrandLObonferroni.conflict <- NA; FDrandHIbonferroni.conflict <- NA; PDrand.conflict <- NA;
	  	PDrandLO.conflict <- NA; PDrandHI.conflict <- NA; 
	  	PDrandLObonferroni.conflict <- NA; PDrandHIbonferroni.conflict <- NA} else
	 
	if(SR.remaining == SR.0){FD.conflict <- 1; FDrand.conflict <- 1; FDrandLO.conflict <- 1; FDrandHI.conflict <- 1; 
	  	FDrandLObonferroni.conflict <- 1; FDrandHIbonferroni.conflict <- 1; PDrand.conflict <- 1;
	  	PDrandLO.conflict <- 1; PDrandHI.conflict <- 1; 
	  	PDrandLObonferroni.conflict <- 1; PDrandHIbonferroni.conflict <- 1} else {	
		
	speciestraits.fd <- subset(speciestraits, select = -c(species.phylog))
	fdcalc <- FD::dbFD(speciestraits.fd, m = 4)
	FD.conflict <- as.numeric(fdcalc$FRic) / FD.0

	FD.r <- vector(length = numrands)
	PD.r <- vector(length = numrands)
	for(r in 1:numrands){	
	   tryCatch({
		#r=1
		spp.r <- speciestraitsXY[sample(nrow(speciestraitsXY), size = SR.remaining, replace = F),]
		spp.r.fd <- subset(spp.r, select = -c(species.phylog))	
		fdcalc <- FD::dbFD(spp.r.fd, m = 4)
		FD.r[r] <- as.numeric(fdcalc$FRic) / FD.0
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(spp.r)))
		names(phymat) <- spp.r$species.phylog 
		PD.r[r] <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0	
		rm("spp.r", "spp.r.fd", "fdcalc", "phymat")
	   }, error=function(e){}) # end of the tryCatch function
	} # end r loop
	FDrand.conflict <- mean(FD.r, na.rm=T) 
	FDrandLO.conflict <- quantile(FD.r, probs=c(0.025), na.rm=T)
	FDrandHI.conflict <- quantile(FD.r, probs=c(0.975), na.rm=T)
	FDrandLObonferroni.conflict <- quantile(FD.r, probs=c(bc), na.rm=T)
	FDrandHIbonferroni.conflict <- quantile(FD.r, probs=c(1-bc), na.rm=T)
	PDrand.conflict <- mean(PD.r, na.rm=T); 
	PDrandLO.conflict <- quantile(PD.r, probs=c(0.025), na.rm=T) 
	PDrandHI.conflict <- quantile(PD.r, probs=c(0.975), na.rm=T)
	PDrandLObonferroni.conflict <- quantile(PD.r, probs=c(bc), na.rm=T) 
	PDrandHIbonferroni.conflict <- quantile(PD.r, probs=c(1-bc), na.rm=T) 
	rm(FD.r, PD.r)
	}  # end if loop
	rm(remaining_spp, SR.remaining, speciestraits)
		


		
	#----- Spp impacts: Non-native species
	# Removing species where the threat is major (1) and causing population decline
	remaining_spp <- datXY
	remaining_spp$cond <- ifelse(remaining_spp$trend == "Decreasing" & remaining_spp$NonNatives == 1, 1, 0)
	remaining_spp <- subset(remaining_spp, cond != 1)
	SR.remaining <- nrow(remaining_spp)
	SR.nonnat <- SR.remaining
	numspploss.nonnat <- SR.0 - nrow(remaining_spp)
	speciestraits <- cbind.data.frame(species.phylog= remaining_spp$species.phylog,
		DietInv= remaining_spp$DietInv, 
	      DietVert= remaining_spp$DietVert, DietFish= remaining_spp$DietFish, 
	   	DietScav= remaining_spp$DietScav, DietFruit= remaining_spp$DietFruit, 
	   	DietNect= remaining_spp$DietNect, DietSeed= remaining_spp$DietSeed, 
	   	DietHerb= remaining_spp$DietHerb, BodyMass= remaining_spp$BodyMass, 
	   	Ground= remaining_spp$Ground, Climbing= remaining_spp$Climbing, 
	   	Volant= remaining_spp$Volant)
	row.names(speciestraits) <- remaining_spp$species
		
	# PD
	if(SR.remaining == 0){PD.nonnat <- 0} else 
	if(SR.remaining == SR.0){PD.nonnat <- 1} else {
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(remaining_spp)))
		names(phymat) <- speciestraits$species.phylog
		PD.nonnat <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0		}

	# FD			
	if(SR.remaining < 2){FD.nonnat <- NA; FDrand.nonnat <- NA; FDrandLO.nonnat <- NA; FDrandHI.nonnat <- NA; 
	  	FDrandLObonferroni.nonnat <- NA; FDrandHIbonferroni.nonnat <- NA; PDrand.nonnat <- NA;
	  	PDrandLO.nonnat <- NA; PDrandHI.nonnat <- NA; 
	  	PDrandLObonferroni.nonnat <- NA; PDrandHIbonferroni.nonnat <- NA} else
	 
	if(SR.remaining == SR.0){FD.nonnat <- 1; FDrand.nonnat <- 1; FDrandLO.nonnat <- 1; FDrandHI.nonnat <- 1; 
	  	FDrandLObonferroni.nonnat <- 1; FDrandHIbonferroni.nonnat <- 1; PDrand.nonnat <- 1;
	  	PDrandLO.nonnat <- 1; PDrandHI.nonnat <- 1; 
	  	PDrandLObonferroni.nonnat <- 1; PDrandHIbonferroni.nonnat <- 1} else {	
		
	speciestraits.fd <- subset(speciestraits, select = -c(species.phylog))
	fdcalc <- FD::dbFD(speciestraits.fd, m = 4)
	FD.nonnat <- as.numeric(fdcalc$FRic) / FD.0

	FD.r <- vector(length = numrands)
	PD.r <- vector(length = numrands)
	for(r in 1:numrands){	
	   tryCatch({
		#r=1
		spp.r <- speciestraitsXY[sample(nrow(speciestraitsXY), size = SR.remaining, replace = F),]
		spp.r.fd <- subset(spp.r, select = -c(species.phylog))	
		fdcalc <- FD::dbFD(spp.r.fd, m = 4)
		FD.r[r] <- as.numeric(fdcalc$FRic) / FD.0
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(spp.r)))
		names(phymat) <- spp.r$species.phylog 
		PD.r[r] <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0	
		rm("spp.r", "spp.r.fd", "fdcalc", "phymat")
	   }, error=function(e){}) # end of the tryCatch function
	} # end r loop
	FDrand.nonnat <- mean(FD.r, na.rm=T) 
	FDrandLO.nonnat <- quantile(FD.r, probs=c(0.025), na.rm=T)
	FDrandHI.nonnat <- quantile(FD.r, probs=c(0.975), na.rm=T)
	FDrandLObonferroni.nonnat <- quantile(FD.r, probs=c(bc), na.rm=T)
	FDrandHIbonferroni.nonnat <- quantile(FD.r, probs=c(1-bc), na.rm=T)
	PDrand.nonnat <- mean(PD.r, na.rm=T); 
	PDrandLO.nonnat <- quantile(PD.r, probs=c(0.025), na.rm=T) 
	PDrandHI.nonnat <- quantile(PD.r, probs=c(0.975), na.rm=T)
	PDrandLObonferroni.nonnat <- quantile(PD.r, probs=c(bc), na.rm=T) 
	PDrandHIbonferroni.nonnat <- quantile(PD.r, probs=c(1-bc), na.rm=T) 
	rm(FD.r, PD.r)
	}  # end if loop
	rm(remaining_spp, SR.remaining, speciestraits)
		


		
	#----- Spp impacts: Pollution
	# Removing species where the threat is major (1) and causing population decline
	remaining_spp <- datXY
	remaining_spp$cond <- ifelse(remaining_spp$trend == "Decreasing" & remaining_spp$pollution == 1, 1, 0)
	remaining_spp <- subset(remaining_spp, cond != 1)
	SR.remaining <- nrow(remaining_spp)
	SR.pollution <- SR.remaining
	numspploss.pollution <- SR.0 - nrow(remaining_spp)
	speciestraits <- cbind.data.frame(species.phylog= remaining_spp$species.phylog,
		DietInv= remaining_spp$DietInv, 
	      DietVert= remaining_spp$DietVert, DietFish= remaining_spp$DietFish, 
	   	DietScav= remaining_spp$DietScav, DietFruit= remaining_spp$DietFruit, 
	   	DietNect= remaining_spp$DietNect, DietSeed= remaining_spp$DietSeed, 
	   	DietHerb= remaining_spp$DietHerb, BodyMass= remaining_spp$BodyMass, 
	   	Ground= remaining_spp$Ground, Climbing= remaining_spp$Climbing, 
	   	Volant= remaining_spp$Volant)
	row.names(speciestraits) <- remaining_spp$species
		
	# PD
	if(SR.remaining == 0){PD.pollution <- 0} else 
	if(SR.remaining == SR.0){PD.pollution <- 1} else {
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(remaining_spp)))
		names(phymat) <- speciestraits$species.phylog
		PD.pollution <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0		}

	# FD			
	if(SR.remaining < 2){FD.pollution <- NA; FDrand.pollution <- NA; FDrandLO.pollution <- NA; FDrandHI.pollution <- NA; 
	  	FDrandLObonferroni.pollution <- NA; FDrandHIbonferroni.pollution <- NA; PDrand.pollution <- NA;
	  	PDrandLO.pollution <- NA; PDrandHI.pollution <- NA; 
	  	PDrandLObonferroni.pollution <- NA; PDrandHIbonferroni.pollution <- NA} else
	 
	if(SR.remaining == SR.0){FD.pollution <- 1; FDrand.pollution <- 1; FDrandLO.pollution <- 1; FDrandHI.pollution <- 1; 
	  	FDrandLObonferroni.pollution <- 1; FDrandHIbonferroni.pollution <- 1; PDrand.pollution <- 1;
	  	PDrandLO.pollution <- 1; PDrandHI.pollution <- 1; 
	  	PDrandLObonferroni.pollution <- 1; PDrandHIbonferroni.pollution <- 1} else {	
		
	speciestraits.fd <- subset(speciestraits, select = -c(species.phylog))
	fdcalc <- FD::dbFD(speciestraits.fd, m = 4)
	FD.pollution <- as.numeric(fdcalc$FRic) / FD.0

	FD.r <- vector(length = numrands)
	PD.r <- vector(length = numrands)
	for(r in 1:numrands){	
	   tryCatch({
		#r=1
		spp.r <- speciestraitsXY[sample(nrow(speciestraitsXY), size = SR.remaining, replace = F),]
		spp.r.fd <- subset(spp.r, select = -c(species.phylog))	
		fdcalc <- FD::dbFD(spp.r.fd, m = 4)
		FD.r[r] <- as.numeric(fdcalc$FRic) / FD.0
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(spp.r)))
		names(phymat) <- spp.r$species.phylog 
		PD.r[r] <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0	
		rm("spp.r", "spp.r.fd", "fdcalc", "phymat")
	   }, error=function(e){}) # end of the tryCatch function
	} # end r loop
	FDrand.pollution <- mean(FD.r, na.rm=T) 
	FDrandLO.pollution <- quantile(FD.r, probs=c(0.025), na.rm=T)
	FDrandHI.pollution <- quantile(FD.r, probs=c(0.975), na.rm=T)
	FDrandLObonferroni.pollution <- quantile(FD.r, probs=c(bc), na.rm=T)
	FDrandHIbonferroni.pollution <- quantile(FD.r, probs=c(1-bc), na.rm=T)
	PDrand.pollution <- mean(PD.r, na.rm=T); 
	PDrandLO.pollution <- quantile(PD.r, probs=c(0.025), na.rm=T) 
	PDrandHI.pollution <- quantile(PD.r, probs=c(0.975), na.rm=T)
	PDrandLObonferroni.pollution <- quantile(PD.r, probs=c(bc), na.rm=T) 
	PDrandHIbonferroni.pollution <- quantile(PD.r, probs=c(1-bc), na.rm=T) 
	rm(FD.r, PD.r)
	}  # end if loop
	rm(remaining_spp, SR.remaining, speciestraits)
		


		
	#----- Spp impacts: Hybridization
	# Removing species where the threat is major (1) and causing population decline
	remaining_spp <- datXY
	remaining_spp$cond <- ifelse(remaining_spp$trend == "Decreasing" & remaining_spp$hybrid == 1, 1, 0)
	remaining_spp <- subset(remaining_spp, cond != 1)
	SR.remaining <- nrow(remaining_spp)
	SR.hybrid <- SR.remaining
	numspploss.hybrid <- SR.0 - nrow(remaining_spp)
	speciestraits <- cbind.data.frame(species.phylog= remaining_spp$species.phylog,
		DietInv= remaining_spp$DietInv, 
	      DietVert= remaining_spp$DietVert, DietFish= remaining_spp$DietFish, 
	   	DietScav= remaining_spp$DietScav, DietFruit= remaining_spp$DietFruit, 
	   	DietNect= remaining_spp$DietNect, DietSeed= remaining_spp$DietSeed, 
	   	DietHerb= remaining_spp$DietHerb, BodyMass= remaining_spp$BodyMass, 
	   	Ground= remaining_spp$Ground, Climbing= remaining_spp$Climbing, 
	   	Volant= remaining_spp$Volant)
	row.names(speciestraits) <- remaining_spp$species
		
	# PD
	if(SR.remaining == 0){PD.hybrid <- 0} else 
	if(SR.remaining == SR.0){PD.hybrid <- 1} else {
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(remaining_spp)))
		names(phymat) <- speciestraits$species.phylog
		PD.hybrid <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0		}

	# FD			
	if(SR.remaining < 2){FD.hybrid <- NA; FDrand.hybrid <- NA; FDrandLO.hybrid <- NA; FDrandHI.hybrid <- NA; 
	  	FDrandLObonferroni.hybrid <- NA; FDrandHIbonferroni.hybrid <- NA; PDrand.hybrid <- NA;
	  	PDrandLO.hybrid <- NA; PDrandHI.hybrid <- NA; 
	  	PDrandLObonferroni.hybrid <- NA; PDrandHIbonferroni.hybrid <- NA} else
	 
	if(SR.remaining == SR.0){FD.hybrid <- 1; FDrand.hybrid <- 1; FDrandLO.hybrid <- 1; FDrandHI.hybrid <- 1; 
	  	FDrandLObonferroni.hybrid <- 1; FDrandHIbonferroni.hybrid <- 1; PDrand.hybrid <- 1;
	  	PDrandLO.hybrid <- 1; PDrandHI.hybrid <- 1; 
	  	PDrandLObonferroni.hybrid <- 1; PDrandHIbonferroni.hybrid <- 1} else {	
		
	speciestraits.fd <- subset(speciestraits, select = -c(species.phylog))
	fdcalc <- FD::dbFD(speciestraits.fd, m = 4)
	FD.hybrid <- as.numeric(fdcalc$FRic) / FD.0

	FD.r <- vector(length = numrands)
	PD.r <- vector(length = numrands)
	for(r in 1:numrands){	
	   tryCatch({
		#r=1
		spp.r <- speciestraitsXY[sample(nrow(speciestraitsXY), size = SR.remaining, replace = F),]
		spp.r.fd <- subset(spp.r, select = -c(species.phylog))	
		fdcalc <- FD::dbFD(spp.r.fd, m = 4)
		FD.r[r] <- as.numeric(fdcalc$FRic) / FD.0
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(spp.r)))
		names(phymat) <- spp.r$species.phylog 
		PD.r[r] <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0	
		rm("spp.r", "spp.r.fd", "fdcalc", "phymat")
	   }, error=function(e){}) # end of the tryCatch function
	} # end r loop
	FDrand.hybrid <- mean(FD.r, na.rm=T) 
	FDrandLO.hybrid <- quantile(FD.r, probs=c(0.025), na.rm=T)
	FDrandHI.hybrid <- quantile(FD.r, probs=c(0.975), na.rm=T)
	FDrandLObonferroni.hybrid <- quantile(FD.r, probs=c(bc), na.rm=T)
	FDrandHIbonferroni.hybrid <- quantile(FD.r, probs=c(1-bc), na.rm=T)
	PDrand.hybrid <- mean(PD.r, na.rm=T); 
	PDrandLO.hybrid <- quantile(PD.r, probs=c(0.025), na.rm=T) 
	PDrandHI.hybrid <- quantile(PD.r, probs=c(0.975), na.rm=T)
	PDrandLObonferroni.hybrid <- quantile(PD.r, probs=c(bc), na.rm=T) 
	PDrandHIbonferroni.hybrid <- quantile(PD.r, probs=c(1-bc), na.rm=T) 
	rm(FD.r, PD.r)
	}  # end if loop
	rm(remaining_spp, SR.remaining, speciestraits)
		



	#----- Spp impacts: Prey depletion
	# Removing species where the threat is major (1) and causing population decline
	remaining_spp <- datXY
	remaining_spp$cond <- ifelse(remaining_spp$trend == "Decreasing" & remaining_spp$prey == 1, 1, 0)
	remaining_spp <- subset(remaining_spp, cond != 1)
	SR.remaining <- nrow(remaining_spp)
	SR.prey <- SR.remaining
	numspploss.prey <- SR.0 - nrow(remaining_spp)
	speciestraits <- cbind.data.frame(species.phylog= remaining_spp$species.phylog,
		DietInv= remaining_spp$DietInv, 
	      DietVert= remaining_spp$DietVert, DietFish= remaining_spp$DietFish, 
	   	DietScav= remaining_spp$DietScav, DietFruit= remaining_spp$DietFruit, 
	   	DietNect= remaining_spp$DietNect, DietSeed= remaining_spp$DietSeed, 
	   	DietHerb= remaining_spp$DietHerb, BodyMass= remaining_spp$BodyMass, 
	   	Ground= remaining_spp$Ground, Climbing= remaining_spp$Climbing, 
	   	Volant= remaining_spp$Volant)
	row.names(speciestraits) <- remaining_spp$species
		
	# PD
	if(SR.remaining == 0){PD.prey <- 0} else 
	if(SR.remaining == SR.0){PD.prey <- 1} else {
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(remaining_spp)))
		names(phymat) <- speciestraits$species.phylog
		PD.prey <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0		}

	# FD			
	if(SR.remaining < 2){FD.prey <- NA; FDrand.prey <- NA; FDrandLO.prey <- NA; FDrandHI.prey <- NA; 
	  	FDrandLObonferroni.prey <- NA; FDrandHIbonferroni.prey <- NA; PDrand.prey <- NA;
	  	PDrandLO.prey <- NA; PDrandHI.prey <- NA; 
	  	PDrandLObonferroni.prey <- NA; PDrandHIbonferroni.prey <- NA} else
	 
	if(SR.remaining == SR.0){FD.prey <- 1; FDrand.prey <- 1; FDrandLO.prey <- 1; FDrandHI.prey <- 1; 
	  	FDrandLObonferroni.prey <- 1; FDrandHIbonferroni.prey <- 1; PDrand.prey <- 1;
	  	PDrandLO.prey <- 1; PDrandHI.prey <- 1; 
	  	PDrandLObonferroni.prey <- 1; PDrandHIbonferroni.prey <- 1} else {	
		
	speciestraits.fd <- subset(speciestraits, select = -c(species.phylog))
	fdcalc <- FD::dbFD(speciestraits.fd, m = 4)
	FD.prey <- as.numeric(fdcalc$FRic) / FD.0

	FD.r <- vector(length = numrands)
	PD.r <- vector(length = numrands)
	for(r in 1:numrands){	
	   tryCatch({
		#r=1
		spp.r <- speciestraitsXY[sample(nrow(speciestraitsXY), size = SR.remaining, replace = F),]
		spp.r.fd <- subset(spp.r, select = -c(species.phylog))	
		fdcalc <- FD::dbFD(spp.r.fd, m = 4)
		FD.r[r] <- as.numeric(fdcalc$FRic) / FD.0
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(spp.r)))
		names(phymat) <- spp.r$species.phylog 
		PD.r[r] <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0	
		rm("spp.r", "spp.r.fd", "fdcalc", "phymat")
	   }, error=function(e){}) # end of the tryCatch function
	} # end r loop
	FDrand.prey <- mean(FD.r, na.rm=T) 
	FDrandLO.prey <- quantile(FD.r, probs=c(0.025), na.rm=T)
	FDrandHI.prey <- quantile(FD.r, probs=c(0.975), na.rm=T)
	FDrandLObonferroni.prey <- quantile(FD.r, probs=c(bc), na.rm=T)
	FDrandHIbonferroni.prey <- quantile(FD.r, probs=c(1-bc), na.rm=T)
	PDrand.prey <- mean(PD.r, na.rm=T); 
	PDrandLO.prey <- quantile(PD.r, probs=c(0.025), na.rm=T) 
	PDrandHI.prey <- quantile(PD.r, probs=c(0.975), na.rm=T)
	PDrandLObonferroni.prey <- quantile(PD.r, probs=c(bc), na.rm=T) 
	PDrandHIbonferroni.prey <- quantile(PD.r, probs=c(1-bc), na.rm=T) 
	rm(FD.r, PD.r)
	}  # end if loop
	rm(remaining_spp, SR.remaining, speciestraits)
		



	#----- Spp impacts: Disease
	# Removing species where the threat is major (1) and causing population decline
	remaining_spp <- datXY
	remaining_spp$cond <- ifelse(remaining_spp$trend == "Decreasing" & remaining_spp$disease == 1, 1, 0)
	remaining_spp <- subset(remaining_spp, cond != 1)
	SR.remaining <- nrow(remaining_spp)
	SR.disease <- SR.remaining
	numspploss.disease <- SR.0 - nrow(remaining_spp)
	speciestraits <- cbind.data.frame(species.phylog= remaining_spp$species.phylog,
		DietInv= remaining_spp$DietInv, 
	      DietVert= remaining_spp$DietVert, DietFish= remaining_spp$DietFish, 
	   	DietScav= remaining_spp$DietScav, DietFruit= remaining_spp$DietFruit, 
	   	DietNect= remaining_spp$DietNect, DietSeed= remaining_spp$DietSeed, 
	   	DietHerb= remaining_spp$DietHerb, BodyMass= remaining_spp$BodyMass, 
	   	Ground= remaining_spp$Ground, Climbing= remaining_spp$Climbing, 
	   	Volant= remaining_spp$Volant)
	row.names(speciestraits) <- remaining_spp$species
		
	# PD
	if(SR.remaining == 0){PD.disease <- 0} else 
	if(SR.remaining == SR.0){PD.disease <- 1} else {
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(remaining_spp)))
		names(phymat) <- speciestraits$species.phylog
		PD.disease <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0		}

	# FD			
	if(SR.remaining < 2){FD.disease <- NA; FDrand.disease <- NA; FDrandLO.disease <- NA; FDrandHI.disease <- NA; 
	  	FDrandLObonferroni.disease <- NA; FDrandHIbonferroni.disease <- NA; PDrand.disease <- NA;
	  	PDrandLO.disease <- NA; PDrandHI.disease <- NA; 
	  	PDrandLObonferroni.disease <- NA; PDrandHIbonferroni.disease <- NA} else
	 
	if(SR.remaining == SR.0){FD.disease <- 1; FDrand.disease <- 1; FDrandLO.disease <- 1; FDrandHI.disease <- 1; 
	  	FDrandLObonferroni.disease <- 1; FDrandHIbonferroni.disease <- 1; PDrand.disease <- 1;
	  	PDrandLO.disease <- 1; PDrandHI.disease <- 1; 
	  	PDrandLObonferroni.disease <- 1; PDrandHIbonferroni.disease <- 1} else {	
		
	speciestraits.fd <- subset(speciestraits, select = -c(species.phylog))
	fdcalc <- FD::dbFD(speciestraits.fd, m = 4)
	FD.disease <- as.numeric(fdcalc$FRic) / FD.0

	FD.r <- vector(length = numrands)
	PD.r <- vector(length = numrands)
	for(r in 1:numrands){	
	   tryCatch({
		#r=1
		spp.r <- speciestraitsXY[sample(nrow(speciestraitsXY), size = SR.remaining, replace = F),]
		spp.r.fd <- subset(spp.r, select = -c(species.phylog))	
		fdcalc <- FD::dbFD(spp.r.fd, m = 4)
		FD.r[r] <- as.numeric(fdcalc$FRic) / FD.0
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(spp.r)))
		names(phymat) <- spp.r$species.phylog 
		PD.r[r] <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0	
		rm("spp.r", "spp.r.fd", "fdcalc", "phymat")
	   }, error=function(e){}) # end of the tryCatch function
	} # end r loop
	FDrand.disease <- mean(FD.r, na.rm=T) 
	FDrandLO.disease <- quantile(FD.r, probs=c(0.025), na.rm=T)
	FDrandHI.disease <- quantile(FD.r, probs=c(0.975), na.rm=T)
	FDrandLObonferroni.disease <- quantile(FD.r, probs=c(bc), na.rm=T)
	FDrandHIbonferroni.disease <- quantile(FD.r, probs=c(1-bc), na.rm=T)
	PDrand.disease <- mean(PD.r, na.rm=T); 
	PDrandLO.disease <- quantile(PD.r, probs=c(0.025), na.rm=T) 
	PDrandHI.disease <- quantile(PD.r, probs=c(0.975), na.rm=T)
	PDrandLObonferroni.disease <- quantile(PD.r, probs=c(bc), na.rm=T) 
	PDrandHIbonferroni.disease <- quantile(PD.r, probs=c(1-bc), na.rm=T) 
	rm(FD.r, PD.r)
	}  # end if loop
	rm(remaining_spp, SR.remaining, speciestraits)
		



	#----- Spp impacts: Inbreeding
	# Removing species where the threat is major (1) and causing population decline
	remaining_spp <- datXY
	remaining_spp$cond <- ifelse(remaining_spp$trend == "Decreasing" & remaining_spp$inbreeding == 1, 1, 0)
	remaining_spp <- subset(remaining_spp, cond != 1)
	SR.remaining <- nrow(remaining_spp)
	SR.inbreeding <- SR.remaining
	numspploss.inbreeding <- SR.0 - nrow(remaining_spp)
	speciestraits <- cbind.data.frame(species.phylog= remaining_spp$species.phylog,
		DietInv= remaining_spp$DietInv, 
	      DietVert= remaining_spp$DietVert, DietFish= remaining_spp$DietFish, 
	   	DietScav= remaining_spp$DietScav, DietFruit= remaining_spp$DietFruit, 
	   	DietNect= remaining_spp$DietNect, DietSeed= remaining_spp$DietSeed, 
	   	DietHerb= remaining_spp$DietHerb, BodyMass= remaining_spp$BodyMass, 
	   	Ground= remaining_spp$Ground, Climbing= remaining_spp$Climbing, 
	   	Volant= remaining_spp$Volant)
	row.names(speciestraits) <- remaining_spp$species
		
	# PD
	if(SR.remaining == 0){PD.inbreeding <- 0} else 
	if(SR.remaining == SR.0){PD.inbreeding <- 1} else {
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(remaining_spp)))
		names(phymat) <- speciestraits$species.phylog
		PD.inbreeding <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0		}

	# FD			
	if(SR.remaining < 2){FD.inbreeding <- NA; FDrand.inbreeding <- NA; FDrandLO.inbreeding <- NA; FDrandHI.inbreeding <- NA; 
	  	FDrandLObonferroni.inbreeding <- NA; FDrandHIbonferroni.inbreeding <- NA; PDrand.inbreeding <- NA;
	  	PDrandLO.inbreeding <- NA; PDrandHI.inbreeding <- NA; 
	  	PDrandLObonferroni.inbreeding <- NA; PDrandHIbonferroni.inbreeding <- NA} else
	 
	if(SR.remaining == SR.0){FD.inbreeding <- 1; FDrand.inbreeding <- 1; FDrandLO.inbreeding <- 1; FDrandHI.inbreeding <- 1; 
	  	FDrandLObonferroni.inbreeding <- 1; FDrandHIbonferroni.inbreeding <- 1; PDrand.inbreeding <- 1;
	  	PDrandLO.inbreeding <- 1; PDrandHI.inbreeding <- 1; 
	  	PDrandLObonferroni.inbreeding <- 1; PDrandHIbonferroni.inbreeding <- 1} else {	
		
	speciestraits.fd <- subset(speciestraits, select = -c(species.phylog))
	fdcalc <- FD::dbFD(speciestraits.fd, m = 4)
	FD.inbreeding <- as.numeric(fdcalc$FRic) / FD.0

	FD.r <- vector(length = numrands)
	PD.r <- vector(length = numrands)
	for(r in 1:numrands){	
	   tryCatch({
		#r=1
		spp.r <- speciestraitsXY[sample(nrow(speciestraitsXY), size = SR.remaining, replace = F),]
		spp.r.fd <- subset(spp.r, select = -c(species.phylog))	
		fdcalc <- FD::dbFD(spp.r.fd, m = 4)
		FD.r[r] <- as.numeric(fdcalc$FRic) / FD.0
		phymat <- data.frame(matrix(1, nrow=1, ncol=nrow(spp.r)))
		names(phymat) <- spp.r$species.phylog 
		PD.r[r] <- picante::pd(phymat, spptree, include.root = TRUE)$PD / PD.0	
		rm("spp.r", "spp.r.fd", "fdcalc", "phymat")
	   }, error=function(e){}) # end of the tryCatch function
	} # end r loop
	FDrand.inbreeding <- mean(FD.r, na.rm=T) 
	FDrandLO.inbreeding <- quantile(FD.r, probs=c(0.025), na.rm=T)
	FDrandHI.inbreeding <- quantile(FD.r, probs=c(0.975), na.rm=T)
	FDrandLObonferroni.inbreeding <- quantile(FD.r, probs=c(bc), na.rm=T)
	FDrandHIbonferroni.inbreeding <- quantile(FD.r, probs=c(1-bc), na.rm=T)
	PDrand.inbreeding <- mean(PD.r, na.rm=T); 
	PDrandLO.inbreeding <- quantile(PD.r, probs=c(0.025), na.rm=T) 
	PDrandHI.inbreeding <- quantile(PD.r, probs=c(0.975), na.rm=T)
	PDrandLObonferroni.inbreeding <- quantile(PD.r, probs=c(bc), na.rm=T) 
	PDrandHIbonferroni.inbreeding <- quantile(PD.r, probs=c(1-bc), na.rm=T) 
	rm(FD.r, PD.r)
	}  # end if loop
	rm(remaining_spp, SR.remaining, speciestraits)
		

  

	#----- Assemble the results for iteration i
	outmat$SR.0[i] <- SR.0
	outmat$SR.allthreats[i] <- SR.allthreats
	outmat$SR.habitat[i] <- SR.habitat
	outmat$SR.hunting[i] <- SR.hunting
	outmat$SR.climate[i] <- SR.climate
	outmat$SR.conflict[i] <- SR.conflict
	outmat$SR.nonnat[i] <- SR.nonnat
	outmat$SR.pollution[i] <- SR.pollution
	outmat$SR.hybrid[i] <- SR.hybrid
	outmat$SR.prey[i] <- SR.prey
	outmat$SR.disease[i] <- SR.disease
	outmat$SR.inbreeding[i] <- SR.inbreeding
	outmat$FD.0[i] <- FD.0
	outmat$FD.allthreats[i] <- FD.allthreats
	outmat$FD.habitat[i] <- FD.habitat
	outmat$FD.hunting[i] <- FD.hunting
	outmat$FD.climate[i] <- FD.climate
	outmat$FD.conflict[i] <- FD.conflict
	outmat$FD.nonnat[i] <- FD.nonnat
	outmat$FD.pollution[i] <- FD.pollution
	outmat$FD.hybrid[i] <- FD.hybrid
	outmat$FD.prey[i] <- FD.prey
	outmat$FD.disease[i] <- FD.disease
	outmat$FD.inbreeding[i] <- FD.inbreeding
	outmat$FDrand.allthreats[i] <- FDrand.allthreats
	outmat$FDrand.habitat[i] <- FDrand.habitat
	outmat$FDrand.hunting[i] <- FDrand.hunting
	outmat$FDrand.climate[i] <- FDrand.climate
	outmat$FDrand.conflict[i] <- FDrand.conflict
	outmat$FDrand.nonnat[i] <- FDrand.nonnat
	outmat$FDrand.pollution[i] <- FDrand.pollution
	outmat$FDrand.hybrid[i] <- FDrand.hybrid
	outmat$FDrand.prey[i] <- FDrand.prey
	outmat$FDrand.disease[i] <- FDrand.disease
	outmat$FDrand.inbreeding[i] <- FDrand.inbreeding
	outmat$FDrandLO.allthreats[i] <- FDrandLO.allthreats
	outmat$FDrandLO.habitat[i] <- FDrandLO.habitat
	outmat$FDrandLO.hunting[i] <- FDrandLO.hunting
	outmat$FDrandLO.climate[i] <- FDrandLO.climate
	outmat$FDrandLO.conflict[i] <- FDrandLO.conflict
	outmat$FDrandLO.nonnat[i] <- FDrandLO.nonnat
	outmat$FDrandLO.pollution[i] <- FDrandLO.pollution
	outmat$FDrandLO.hybrid[i] <- FDrandLO.hybrid
	outmat$FDrandLO.prey[i] <- FDrandLO.prey
	outmat$FDrandLO.disease[i] <- FDrandLO.disease
	outmat$FDrandLO.inbreeding[i] <- FDrandLO.inbreeding
	outmat$FDrandHI.allthreats[i] <- FDrandHI.allthreats
	outmat$FDrandHI.habitat[i] <- FDrandHI.habitat
	outmat$FDrandHI.hunting[i] <- FDrandHI.hunting
	outmat$FDrandHI.climate[i] <- FDrandHI.climate
	outmat$FDrandHI.conflict[i] <- FDrandHI.conflict
	outmat$FDrandHI.nonnat[i] <- FDrandHI.nonnat
	outmat$FDrandHI.pollution[i] <- FDrandHI.pollution
	outmat$FDrandHI.hybrid[i] <- FDrandHI.hybrid
	outmat$FDrandHI.prey[i] <- FDrandHI.prey
	outmat$FDrandHI.disease[i] <- FDrandHI.disease
	outmat$FDrandHI.inbreeding[i] <- FDrandHI.inbreeding
	outmat$FDrandLObonferroni.allthreats[i] <- FDrandLObonferroni.allthreats
	outmat$FDrandLObonferroni.habitat[i] <- FDrandLObonferroni.habitat
	outmat$FDrandLObonferroni.hunting[i] <- FDrandLObonferroni.hunting
	outmat$FDrandLObonferroni.climate[i] <- FDrandLObonferroni.climate
	outmat$FDrandLObonferroni.conflict[i] <- FDrandLObonferroni.conflict
	outmat$FDrandLObonferroni.nonnat[i] <- FDrandLObonferroni.nonnat
	outmat$FDrandLObonferroni.pollution[i] <- FDrandLObonferroni.pollution
	outmat$FDrandLObonferroni.hybrid[i] <- FDrandLObonferroni.hybrid
	outmat$FDrandLObonferroni.prey[i] <- FDrandLObonferroni.prey
	outmat$FDrandLObonferroni.disease[i] <- FDrandLObonferroni.disease
	outmat$FDrandLObonferroni.inbreeding[i] <- FDrandLObonferroni.inbreeding
	outmat$FDrandHIbonferroni.allthreats[i] <- FDrandHIbonferroni.allthreats
	outmat$FDrandHIbonferroni.habitat[i] <- FDrandHIbonferroni.habitat
	outmat$FDrandHIbonferroni.hunting[i] <- FDrandHIbonferroni.hunting
	outmat$FDrandHIbonferroni.climate[i] <- FDrandHIbonferroni.climate
	outmat$FDrandHIbonferroni.conflict[i] <- FDrandHIbonferroni.conflict
	outmat$FDrandHIbonferroni.nonnat[i] <- FDrandHIbonferroni.nonnat
	outmat$FDrandHIbonferroni.pollution[i] <- FDrandHIbonferroni.pollution
	outmat$FDrandHIbonferroni.hybrid[i] <- FDrandHIbonferroni.hybrid
	outmat$FDrandHIbonferroni.prey[i] <- FDrandHIbonferroni.prey
	outmat$FDrandHIbonferroni.disease[i] <- FDrandHIbonferroni.disease
	outmat$FDrandHIbonferroni.inbreeding[i] <- FDrandHIbonferroni.inbreeding
	outmat$PD.0[i] <- PD.0
	outmat$PD.allthreats[i] <- PD.allthreats
	outmat$PD.habitat[i] <- PD.habitat
	outmat$PD.hunting[i] <- PD.hunting
	outmat$PD.climate[i] <- PD.climate
	outmat$PD.conflict[i] <- PD.conflict
	outmat$PD.nonnat[i] <- PD.nonnat
	outmat$PD.pollution[i] <- PD.pollution
	outmat$PD.hybrid[i] <- PD.hybrid
	outmat$PD.prey[i] <- PD.prey
	outmat$PD.disease[i] <- PD.disease
	outmat$PD.inbreeding[i] <- PD.inbreeding
	outmat$PDrand.allthreats[i] <- PDrand.allthreats
	outmat$PDrand.habitat[i] <- PDrand.habitat
	outmat$PDrand.hunting[i] <- PDrand.hunting
	outmat$PDrand.climate[i] <- PDrand.climate
	outmat$PDrand.conflict[i] <- PDrand.conflict
	outmat$PDrand.nonnat[i] <- PDrand.nonnat
	outmat$PDrand.pollution[i] <- PDrand.pollution
	outmat$PDrand.hybrid[i] <- PDrand.hybrid
	outmat$PDrand.prey[i] <- PDrand.prey
	outmat$PDrand.disease[i] <- PDrand.disease
	outmat$PDrand.inbreeding[i] <- PDrand.inbreeding
	outmat$PDrandLO.allthreats[i] <- PDrandLO.allthreats
	outmat$PDrandLO.habitat[i] <- PDrandLO.habitat
	outmat$PDrandLO.hunting[i] <- PDrandLO.hunting
	outmat$PDrandLO.climate[i] <- PDrandLO.climate
	outmat$PDrandLO.conflict[i] <- PDrandLO.conflict
	outmat$PDrandLO.nonnat[i] <- PDrandLO.nonnat
	outmat$PDrandLO.pollution[i] <- PDrandLO.pollution
	outmat$PDrandLO.hybrid[i] <- PDrandLO.hybrid
	outmat$PDrandLO.prey[i] <- PDrandLO.prey
	outmat$PDrandLO.disease[i] <- PDrandLO.disease
	outmat$PDrandLO.inbreeding[i] <- PDrandLO.inbreeding
	outmat$PDrandHI.allthreats[i] <- PDrandHI.allthreats
	outmat$PDrandHI.habitat[i] <- PDrandHI.habitat
	outmat$PDrandHI.hunting[i] <- PDrandHI.hunting
	outmat$PDrandHI.climate[i] <- PDrandHI.climate
	outmat$PDrandHI.conflict[i] <- PDrandHI.conflict
	outmat$PDrandHI.nonnat[i] <- PDrandHI.nonnat
	outmat$PDrandHI.pollution[i] <- PDrandHI.pollution
	outmat$PDrandHI.hybrid[i] <- PDrandHI.hybrid
	outmat$PDrandHI.prey[i] <- PDrandHI.prey
	outmat$PDrandHI.disease[i] <- PDrandHI.disease
	outmat$PDrandHI.inbreeding[i] <- PDrandHI.inbreeding
	outmat$PDrandLObonferroni.allthreats[i] <- PDrandLObonferroni.allthreats
	outmat$PDrandLObonferroni.habitat[i] <- PDrandLObonferroni.habitat
	outmat$PDrandLObonferroni.hunting[i] <- PDrandLObonferroni.hunting
	outmat$PDrandLObonferroni.climate[i] <- PDrandLObonferroni.climate
	outmat$PDrandLObonferroni.conflict[i] <- PDrandLObonferroni.conflict
	outmat$PDrandLObonferroni.nonnat[i] <- PDrandLObonferroni.nonnat
	outmat$PDrandLObonferroni.pollution[i] <- PDrandLObonferroni.pollution
	outmat$PDrandLObonferroni.hybrid[i] <- PDrandLObonferroni.hybrid
	outmat$PDrandLObonferroni.prey[i] <- PDrandLObonferroni.prey
	outmat$PDrandLObonferroni.disease[i] <- PDrandLObonferroni.disease
	outmat$PDrandLObonferroni.inbreeding[i] <- PDrandLObonferroni.inbreeding
	outmat$PDrandHIbonferroni.allthreats[i] <- PDrandHIbonferroni.allthreats
	outmat$PDrandHIbonferroni.habitat[i] <- PDrandHIbonferroni.habitat
	outmat$PDrandHIbonferroni.hunting[i] <- PDrandHIbonferroni.hunting
	outmat$PDrandHIbonferroni.climate[i] <- PDrandHIbonferroni.climate
	outmat$PDrandHIbonferroni.conflict[i] <- PDrandHIbonferroni.conflict
	outmat$PDrandHIbonferroni.nonnat[i] <- PDrandHIbonferroni.nonnat
	outmat$PDrandHIbonferroni.pollution[i] <- PDrandHIbonferroni.pollution
	outmat$PDrandHIbonferroni.hybrid[i] <- PDrandHIbonferroni.hybrid
	outmat$PDrandHIbonferroni.prey[i] <- PDrandHIbonferroni.prey
	outmat$PDrandHIbonferroni.disease[i] <- PDrandHIbonferroni.disease
	outmat$PDrandHIbonferroni.inbreeding[i] <- PDrandHIbonferroni.inbreeding
	outmat$TraitChange.hab.DietInv[i] <- thab.01-t0.01
	outmat$TraitChange.hab.DietVert[i] <-  thab.02-t0.02
	outmat$TraitChange.hab.DietFish[i] <-  thab.03-t0.03
	outmat$TraitChange.hab.DietScav[i] <-  thab.04-t0.04
	outmat$TraitChange.hab.DietFruit[i] <- thab.05-t0.05
	outmat$TraitChange.hab.DietNect[i] <- thab.06-t0.06
	outmat$TraitChange.hab.DietSeed[i] <- thab.07-t0.07
	outmat$TraitChange.hab.DietHerb[i] <- thab.08-t0.08
	outmat$TraitChange.hab.BodyMass[i] <- thab.09-t0.09
	outmat$TraitChange.hab.Ground[i] <- thab.10-t0.10
	outmat$TraitChange.hab.Climbing[i] <- thab.11-t0.11
	outmat$TraitChange.hab.Volant[i] <- thab.12-t0.12
	outmat$TraitChange.hunt.DietInv[i] <- thunt.01-t0.01
	outmat$TraitChange.hunt.DietVert[i] <-  thunt.02-t0.02
	outmat$TraitChange.hunt.DietFish[i] <-  thunt.03-t0.03
	outmat$TraitChange.hunt.DietScav[i] <-  thunt.04-t0.04
	outmat$TraitChange.hunt.DietFruit[i] <- thunt.05-t0.05
	outmat$TraitChange.hunt.DietNect[i] <- thunt.06-t0.06
	outmat$TraitChange.hunt.DietSeed[i] <- thunt.07-t0.07
	outmat$TraitChange.hunt.DietHerb[i] <- thunt.08-t0.08
	outmat$TraitChange.hunt.BodyMass[i] <- thunt.09-t0.09
	outmat$TraitChange.hunt.Ground[i] <- thunt.10-t0.10
	outmat$TraitChange.hunt.Climbing[i] <- thunt.11-t0.11
	outmat$TraitChange.hunt.Volant[i] <- thunt.12-t0.12
	
	rm(SR.0, SR.allthreats, SR.habitat, SR.hunting, SR.climate, SR.conflict, SR.nonnat, SR.pollution, SR.hybrid, SR.prey, SR.disease, SR.inbreeding,  
     	      FD.0, FD.allthreats, FD.habitat, FD.hunting, FD.climate, FD.conflict,  
		FD.nonnat, FD.pollution, FD.hybrid, FD.prey, FD.disease, FD.inbreeding, 
            FDrand.allthreats, FDrand.habitat, FDrand.hunting, FDrand.climate, FDrand.conflict, FDrand.nonnat,  
       	FDrand.pollution, FDrand.hybrid, FDrand.prey, FDrand.disease, FDrand.inbreeding, 	
            FDrandLO.allthreats, FDrandLO.habitat, FDrandLO.hunting, FDrandLO.climate, FDrandLO.conflict, FDrandLO.nonnat,  
		FDrandLO.pollution, FDrandLO.hybrid, FDrandLO.prey, FDrandLO.disease, FDrandLO.inbreeding, 	
            FDrandHI.allthreats, FDrandHI.habitat, FDrandHI.hunting, FDrandHI.climate, FDrandHI.conflict, FDrandHI.nonnat,  
		FDrandHI.pollution, FDrandHI.hybrid, FDrandHI.prey, FDrandHI.disease, FDrandHI.inbreeding, 	
            FDrandLObonferroni.allthreats, FDrandLObonferroni.habitat, FDrandLObonferroni.hunting, FDrandLObonferroni.climate, FDrandLObonferroni.conflict, FDrandLObonferroni.nonnat,  
		FDrandLObonferroni.pollution, FDrandLObonferroni.hybrid, FDrandLObonferroni.prey, FDrandLObonferroni.disease, FDrandLObonferroni.inbreeding, 	
           	FDrandHIbonferroni.allthreats, FDrandHIbonferroni.habitat, FDrandHIbonferroni.hunting, FDrandHIbonferroni.climate, FDrandHIbonferroni.conflict, FDrandHIbonferroni.nonnat,  
		FDrandHIbonferroni.pollution, FDrandHIbonferroni.hybrid, FDrandHIbonferroni.prey, FDrandHIbonferroni.disease, FDrandHIbonferroni.inbreeding, 	
	      PD.0, PD.allthreats, PD.habitat, PD.hunting, PD.climate, PD.conflict,  
		PD.nonnat, PD.pollution, PD.hybrid, PD.prey, PD.disease, PD.inbreeding,  
            PDrand.allthreats, PDrand.habitat, PDrand.hunting, PDrand.climate, PDrand.conflict, PDrand.nonnat,  
		PDrand.pollution, PDrand.hybrid, PDrand.prey, PDrand.disease, PDrand.inbreeding, 	
            PDrandLO.allthreats, PDrandLO.habitat, PDrandLO.hunting, PDrandLO.climate, PDrandLO.conflict, PDrandLO.nonnat,  
		PDrandLO.pollution, PDrandLO.hybrid, PDrandLO.prey, PDrandLO.disease, PDrandLO.inbreeding, 	
            PDrandHI.allthreats, PDrandHI.habitat, PDrandHI.hunting, PDrandHI.climate, PDrandHI.conflict, PDrandHI.nonnat,  
		PDrandHI.pollution, PDrandHI.hybrid, PDrandHI.prey, PDrandHI.disease, PDrandHI.inbreeding, 	
            PDrandLObonferroni.allthreats, PDrandLObonferroni.habitat, PDrandLObonferroni.hunting, PDrandLObonferroni.climate, PDrandLObonferroni.conflict, PDrandLObonferroni.nonnat,  
		PDrandLObonferroni.pollution, PDrandLObonferroni.hybrid, PDrandLObonferroni.prey, PDrandLObonferroni.disease, PDrandLObonferroni.inbreeding, 	
           	PDrandHIbonferroni.allthreats, PDrandHIbonferroni.habitat, PDrandHIbonferroni.hunting, PDrandHIbonferroni.climate, PDrandHIbonferroni.conflict, PDrandHIbonferroni.nonnat,  
		PDrandHIbonferroni.pollution, PDrandHIbonferroni.hybrid, PDrandHIbonferroni.prey, PDrandHIbonferroni.disease, PDrandHIbonferroni.inbreeding, 
		thab.01, thab.02, thab.03, thab.04,	thab.05, thab.06, thab.07, thab.08, thab.09, thab.10, thab.11, thab.12,
		thunt.01, thunt.02, thunt.03, thunt.04, thunt.05, thunt.06, thunt.07, thunt.08, thunt.09, thunt.10, thunt.11, thunt.12)

	write.csv(outmat, "outmat.csv", row.names=F)
	

#}, error=function(e){}) # end of the tryCatch function
}  # end i loop

Sys.time() - start







#----------- ASSEMBLE AND SAVE THE RESULTS MATRIX -------------------------------
#outmat <- data.frame(read.csv("outmat_compiled.csv", header=T))

res <- cbind.data.frame(ctrs_area, outmat)


# Add columns for 'bias' in FD and PD loss 
# Value explanations:
#  1: loss is significantly biased towards functionally (or phylogenetically) unique species
#  0: loss is unbiased
# -1: loss is significantly biased towards functionally (or phylogenetically) redundant species

dat0 <- res

#--- Functional diversity
# FD: all threats
dat0$tmp <- ifelse(dat0$FD.allthreats <= dat0$FDrandLO.allthreats, 1, 0)
dat0$tmp <- ifelse(dat0$FD.allthreats >= dat0$FDrandHI.allthreats, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.allthreats, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbias.allthreats <- as.factor(dat0$tmp)

# FD: habitat
dat0$tmp <- ifelse(dat0$FD.habitat <= dat0$FDrandLO.habitat, 1, 0)
dat0$tmp <- ifelse(dat0$FD.habitat >= dat0$FDrandHI.habitat, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.habitat, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbias.habitat <- as.factor(dat0$tmp)

# FD: hunting
dat0$tmp <- ifelse(dat0$FD.hunting <= dat0$FDrandLO.hunting, 1, 0)
dat0$tmp <- ifelse(dat0$FD.hunting >= dat0$FDrandHI.hunting, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.hunting, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbias.hunting <- as.factor(dat0$tmp)

# FD: climate
dat0$tmp <- ifelse(dat0$FD.climate <= dat0$FDrandLO.climate, 1, 0)
dat0$tmp <- ifelse(dat0$FD.climate >= dat0$FDrandHI.climate, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.climate, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbias.climate <- as.factor(dat0$tmp)

# FD: conflict
dat0$tmp <- ifelse(dat0$FD.conflict <= dat0$FDrandLO.conflict, 1, 0)
dat0$tmp <- ifelse(dat0$FD.conflict >= dat0$FDrandHI.conflict, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.conflict, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbias.conflict <- as.factor(dat0$tmp)

# FD: non-natives
dat0$tmp <- ifelse(dat0$FD.nonnat <= dat0$FDrandLO.nonnat, 1, 0)
dat0$tmp <- ifelse(dat0$FD.nonnat >= dat0$FDrandHI.nonnat, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.nonnat, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbias.nonnat<- as.factor(dat0$tmp)

# FD: pollution
dat0$tmp <- ifelse(dat0$FD.pollution <= dat0$FDrandLO.pollution, 1, 0)
dat0$tmp <- ifelse(dat0$FD.pollution >= dat0$FDrandHI.pollution, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.pollution, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbias.pollution <- as.factor(dat0$tmp)

# FD: hybridization
dat0$tmp <- ifelse(dat0$FD.hybrid <= dat0$FDrandLO.hybrid, 1, 0)
dat0$tmp <- ifelse(dat0$FD.hybrid >= dat0$FDrandHI.hybrid, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.hybrid, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbias.hybrid <- as.factor(dat0$tmp)

# FD: prey depletion
dat0$tmp <- ifelse(dat0$FD.prey <= dat0$FDrandLO.prey, 1, 0)
dat0$tmp <- ifelse(dat0$FD.prey >= dat0$FDrandHI.prey, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.prey, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbias.prey <- as.factor(dat0$tmp)

# FD: disease
dat0$tmp <- ifelse(dat0$FD.disease <= dat0$FDrandLO.disease, 1, 0)
dat0$tmp <- ifelse(dat0$FD.disease >= dat0$FDrandHI.disease, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.disease, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbias.disease <- as.factor(dat0$tmp)

# FD: inbreeding
dat0$tmp <- ifelse(dat0$FD.inbreeding <= dat0$FDrandLO.inbreeding, 1, 0)
dat0$tmp <- ifelse(dat0$FD.inbreeding >= dat0$FDrandHI.inbreeding, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.inbreeding, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbias.inbreeding <- as.factor(dat0$tmp)


#--- Phylogenetic diversity
# PD: all threats
dat0$tmp <- ifelse(dat0$PD.allthreats <= dat0$PDrandLO.allthreats, 1, 0)
dat0$tmp <- ifelse(dat0$PD.allthreats >= dat0$PDrandHI.allthreats, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.allthreats, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbias.allthreats <- as.factor(dat0$tmp)

# PD: habitat
dat0$tmp <- ifelse(dat0$PD.habitat <= dat0$PDrandLO.habitat, 1, 0)
dat0$tmp <- ifelse(dat0$PD.habitat >= dat0$PDrandHI.habitat, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.habitat, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbias.habitat <- as.factor(dat0$tmp)

# PD: hunting
dat0$tmp <- ifelse(dat0$PD.hunting <= dat0$PDrandLO.hunting, 1, 0)
dat0$tmp <- ifelse(dat0$PD.hunting >= dat0$PDrandHI.hunting, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.hunting, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbias.hunting <- as.factor(dat0$tmp)

# PD: climate
dat0$tmp <- ifelse(dat0$PD.climate <= dat0$PDrandLO.climate, 1, 0)
dat0$tmp <- ifelse(dat0$PD.climate >= dat0$PDrandHI.climate, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.climate, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbias.climate <- as.factor(dat0$tmp)

# PD: conflict
dat0$tmp <- ifelse(dat0$PD.conflict <= dat0$PDrandLO.conflict, 1, 0)
dat0$tmp <- ifelse(dat0$PD.conflict >= dat0$PDrandHI.conflict, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.conflict, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbias.conflict <- as.factor(dat0$tmp)

# PD: non-natives
dat0$tmp <- ifelse(dat0$PD.nonnat <= dat0$PDrandLO.nonnat, 1, 0)
dat0$tmp <- ifelse(dat0$PD.nonnat >= dat0$PDrandHI.nonnat, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.nonnat, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbias.nonnat <- as.factor(dat0$tmp)

# PD: pollution
dat0$tmp <- ifelse(dat0$PD.pollution <= dat0$PDrandLO.pollution, 1, 0)
dat0$tmp <- ifelse(dat0$PD.pollution >= dat0$PDrandHI.pollution, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.pollution, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbias.pollution <- as.factor(dat0$tmp)

# PD: hybridization
dat0$tmp <- ifelse(dat0$PD.hybrid <= dat0$PDrandLO.hybrid, 1, 0)
dat0$tmp <- ifelse(dat0$PD.hybrid >= dat0$PDrandHI.hybrid, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.hybrid, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbias.hybrid <- as.factor(dat0$tmp)

# PD: prey depletion
dat0$tmp <- ifelse(dat0$PD.prey <= dat0$PDrandLO.prey, 1, 0)
dat0$tmp <- ifelse(dat0$PD.prey >= dat0$PDrandHI.prey, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.prey, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbias.prey <- as.factor(dat0$tmp)

# PD: disease
dat0$tmp <- ifelse(dat0$PD.disease <= dat0$PDrandLO.disease, 1, 0)
dat0$tmp <- ifelse(dat0$PD.disease >= dat0$PDrandHI.disease, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.disease, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbias.disease <- as.factor(dat0$tmp)

# PD: inbreeding
dat0$tmp <- ifelse(dat0$PD.inbreeding <= dat0$PDrandLO.inbreeding, 1, 0)
dat0$tmp <- ifelse(dat0$PD.inbreeding >= dat0$PDrandHI.inbreeding, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.inbreeding, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbias.inbreeding <- as.factor(dat0$tmp)


#--- Functional diversity --- with Bonferroni correction
# FD: all threats
dat0$tmp <- ifelse(dat0$FD.allthreats <= dat0$FDrandLObonferroni.allthreats, 1, 0)
dat0$tmp <- ifelse(dat0$FD.allthreats >= dat0$FDrandHIbonferroni.allthreats, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.allthreats, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbiasbonferroni.allthreats <- as.factor(dat0$tmp)

# FD: habitat
dat0$tmp <- ifelse(dat0$FD.habitat <= dat0$FDrandLObonferroni.habitat, 1, 0)
dat0$tmp <- ifelse(dat0$FD.habitat >= dat0$FDrandHIbonferroni.habitat, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.habitat, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbiasbonferroni.habitat <- as.factor(dat0$tmp)

# FD: hunting
dat0$tmp <- ifelse(dat0$FD.hunting <= dat0$FDrandLObonferroni.hunting, 1, 0)
dat0$tmp <- ifelse(dat0$FD.hunting >= dat0$FDrandHIbonferroni.hunting, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.hunting, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbiasbonferroni.hunting <- as.factor(dat0$tmp)

# FD: climate
dat0$tmp <- ifelse(dat0$FD.climate <= dat0$FDrandLObonferroni.climate, 1, 0)
dat0$tmp <- ifelse(dat0$FD.climate >= dat0$FDrandHIbonferroni.climate, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.climate, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbiasbonferroni.climate <- as.factor(dat0$tmp)

# FD: conflict
dat0$tmp <- ifelse(dat0$FD.conflict <= dat0$FDrandLObonferroni.conflict, 1, 0)
dat0$tmp <- ifelse(dat0$FD.conflict >= dat0$FDrandHIbonferroni.conflict, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.conflict, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbiasbonferroni.conflict <- as.factor(dat0$tmp)

# FD: non-natives
dat0$tmp <- ifelse(dat0$FD.nonnat <= dat0$FDrandLObonferroni.nonnat, 1, 0)
dat0$tmp <- ifelse(dat0$FD.nonnat >= dat0$FDrandHIbonferroni.nonnat, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.nonnat, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbiasbonferroni.nonnat <- as.factor(dat0$tmp)

# FD: pollution
dat0$tmp <- ifelse(dat0$FD.pollution <= dat0$FDrandLObonferroni.pollution, 1, 0)
dat0$tmp <- ifelse(dat0$FD.pollution >= dat0$FDrandHIbonferroni.pollution, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.pollution, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbiasbonferroni.pollution <- as.factor(dat0$tmp)

# FD: hybridization
dat0$tmp <- ifelse(dat0$FD.hybrid <= dat0$FDrandLObonferroni.hybrid, 1, 0)
dat0$tmp <- ifelse(dat0$FD.hybrid >= dat0$FDrandHIbonferroni.hybrid, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.hybrid, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbiasbonferroni.hybrid <- as.factor(dat0$tmp)

# FD: prey depletion
dat0$tmp <- ifelse(dat0$FD.prey <= dat0$FDrandLObonferroni.prey, 1, 0)
dat0$tmp <- ifelse(dat0$FD.prey >= dat0$FDrandHIbonferroni.prey, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.prey, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbiasbonferroni.prey <- as.factor(dat0$tmp)

# FD: disease
dat0$tmp <- ifelse(dat0$FD.disease <= dat0$FDrandLObonferroni.disease, 1, 0)
dat0$tmp <- ifelse(dat0$FD.disease >= dat0$FDrandHIbonferroni.disease, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.disease, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbiasbonferroni.disease <- as.factor(dat0$tmp)

# FD: inbreeding
dat0$tmp <- ifelse(dat0$FD.inbreeding <= dat0$FDrandLObonferroni.inbreeding, 1, 0)
dat0$tmp <- ifelse(dat0$FD.inbreeding >= dat0$FDrandHIbonferroni.inbreeding, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.inbreeding, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$FDbiasbonferroni.inbreeding <- as.factor(dat0$tmp)


#--- Phylogenetic diversity --- with Bonferroni correction
# PD: all threats
dat0$tmp <- ifelse(dat0$PD.allthreats <= dat0$PDrandLObonferroni.allthreats, 1, 0)
dat0$tmp <- ifelse(dat0$PD.allthreats >= dat0$PDrandHIbonferroni.allthreats, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.allthreats, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbiasbonferroni.allthreats <- as.factor(dat0$tmp)

# PD: habitat
dat0$tmp <- ifelse(dat0$PD.habitat <= dat0$PDrandLObonferroni.habitat, 1, 0)
dat0$tmp <- ifelse(dat0$PD.habitat >= dat0$PDrandHIbonferroni.habitat, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.habitat, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbiasbonferroni.habitat <- as.factor(dat0$tmp)

# PD: hunting
dat0$tmp <- ifelse(dat0$PD.hunting <= dat0$PDrandLObonferroni.hunting, 1, 0)
dat0$tmp <- ifelse(dat0$PD.hunting >= dat0$PDrandHIbonferroni.hunting, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.hunting, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbiasbonferroni.hunting <- as.factor(dat0$tmp)

# PD: climate
dat0$tmp <- ifelse(dat0$PD.climate <= dat0$PDrandLObonferroni.climate, 1, 0)
dat0$tmp <- ifelse(dat0$PD.climate >= dat0$PDrandHIbonferroni.climate, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.climate, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbiasbonferroni.climate <- as.factor(dat0$tmp)

# PD: conflict
dat0$tmp <- ifelse(dat0$PD.conflict <= dat0$PDrandLObonferroni.conflict, 1, 0)
dat0$tmp <- ifelse(dat0$PD.conflict >= dat0$PDrandHIbonferroni.conflict, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.conflict, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbiasbonferroni.conflict <- as.factor(dat0$tmp)

# PD: non-natives
dat0$tmp <- ifelse(dat0$PD.nonnat <= dat0$PDrandLObonferroni.nonnat, 1, 0)
dat0$tmp <- ifelse(dat0$PD.nonnat >= dat0$PDrandHIbonferroni.nonnat, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.nonnat, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbiasbonferroni.nonnat<- as.factor(dat0$tmp)

# PD: pollution
dat0$tmp <- ifelse(dat0$PD.pollution <= dat0$PDrandLObonferroni.pollution, 1, 0)
dat0$tmp <- ifelse(dat0$PD.pollution >= dat0$PDrandHIbonferroni.pollution, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.pollution, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbiasbonferroni.pollution <- as.factor(dat0$tmp)

# PD: hybridization
dat0$tmp <- ifelse(dat0$PD.hybrid <= dat0$PDrandLObonferroni.hybrid, 1, 0)
dat0$tmp <- ifelse(dat0$PD.hybrid >= dat0$PDrandHIbonferroni.hybrid, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.hybrid, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbiasbonferroni.hybrid <- as.factor(dat0$tmp)

# PD: prey depletion
dat0$tmp <- ifelse(dat0$PD.prey <= dat0$PDrandLObonferroni.prey, 1, 0)
dat0$tmp <- ifelse(dat0$PD.prey >= dat0$PDrandHIbonferroni.prey, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.prey, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbiasbonferroni.prey <- as.factor(dat0$tmp)

# PD: disease
dat0$tmp <- ifelse(dat0$PD.disease <= dat0$PDrandLObonferroni.disease, 1, 0)
dat0$tmp <- ifelse(dat0$PD.disease >= dat0$PDrandHIbonferroni.disease, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.disease, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbiasbonferroni.disease <- as.factor(dat0$tmp)

# PD: inbreeding
dat0$tmp <- ifelse(dat0$PD.inbreeding <= dat0$PDrandLObonferroni.inbreeding, 1, 0)
dat0$tmp <- ifelse(dat0$PD.inbreeding >= dat0$PDrandHIbonferroni.inbreeding, -1, dat0$tmp)
dat0$tmp <- ifelse(dat0$SR.0 == dat0$SR.inbreeding, 0, dat0$tmp)
dat0$tmp[is.na(dat0$tmp)] <- 0
dat0$PDbiasbonferroni.inbreeding <- as.factor(dat0$tmp)


dat0 <- subset(dat0, select = -c(tmp))




#------------------- SAVE FILE ------------------------------------------------------
write.csv(dat0, "Results/FuncPhylo_mammals200421.csv", row.names=F) 

elapsed <- Sys.time() - start
elapsed  
















