###############################################################################
#  Functional diversity analysis plots
#  Script to read in results dataframe from diversity analysis and generate plots.
#  Sara Williams
#  June 15, 2019 (modified by JB most recently on 20 Apr 2020)
###############################################################################



# =============================================================================
#  Load packages and set working director.
# =============================================================================
library(tidyr)
library(dplyr)
library(sf)
library(raster)
library(ggplot2)
library(ggpubr)
library(smoothr)
library(cowplot)
library(extrafont)


#setwd("C:/Users/saraw/Documents/FD/")
# Laptop
setwd("C:/Box Sync/Projects (active)/Functional diversity/Analysis")
# Desktop
#setwd("D:/Box Sync/Projects/Projects (active)/Functional diversity/Analysis")



# =============================================================================
#  Load input data and set base parameters
# =============================================================================
rm(list = ls())
dat <- read.csv("Results/FuncPhylo_mammals200421.csv")
st_erase = function(x, y) st_difference(x, st_union(st_combine(y)))

	
	# ----------------------
	#	Projection used in analysis
	prj <- "+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs"
	
	# ----------------------
	#  Countries
	ctrs <- st_read("Data/Raw/UIA_World_Countries_Boundaries.shp") %>%
		dplyr::select(Country, geometry) %>%
		st_transform(st_crs(prj))
	
	# ----------------------
	#  Continents outline
	area_thresh <- units::set_units(500, km^2)
	con_crop <- st_read("Data/Raw/p_template.shp") %>%
		st_transform(prj) %>%
		drop_crumbs(threshold = area_thresh) 
	
	# ----------------------
	#  Make continents nice for plotting
	area_thresh2 <- units::set_units(50000, km^2)
	con_out <- con_crop %>%
		st_buffer(30000) 
		
	# ----------------------
	#	Read in results CSV and convert to sf
	#    Save for future use
	res_df <- dat

	res_df$FDbiasbonferroni.allthreats <- as.factor(res_df$FDbiasbonferroni.allthreats)
	res_df$FDbiasbonferroni.habitat <- as.factor(res_df$FDbiasbonferroni.habitat)
	res_df$FDbiasbonferroni.hunting <- as.factor(res_df$FDbiasbonferroni.hunting)
	res_df$FDbiasbonferroni.climate <- as.factor(res_df$FDbiasbonferroni.climate)
	res_df$FDbiasbonferroni.conflict <- as.factor(res_df$FDbiasbonferroni.conflict)
	res_df$FDbiasbonferroni.nonnat <- as.factor(res_df$FDbiasbonferroni.nonnat)
	res_df$FDbiasbonferroni.pollution <- as.factor(res_df$FDbiasbonferroni.pollution)
	res_df$FDbiasbonferroni.hybrid <- as.factor(res_df$FDbiasbonferroni.hybrid)
	res_df$FDbiasbonferroni.prey <- as.factor(res_df$FDbiasbonferroni.prey)
	res_df$FDbiasbonferroni.disease <- as.factor(res_df$FDbiasbonferroni.disease)
	res_df$FDbiasbonferroni.inbreeding <- as.factor(res_df$FDbiasbonferroni.inbreeding)
	res_df$PDbiasbonferroni.allthreats <- as.factor(res_df$PDbiasbonferroni.allthreats)
	res_df$PDbiasbonferroni.habitat <- as.factor(res_df$PDbiasbonferroni.habitat)
	res_df$PDbiasbonferroni.hunting <- as.factor(res_df$PDbiasbonferroni.hunting)
	res_df$PDbiasbonferroni.climate <- as.factor(res_df$PDbiasbonferroni.climate)
	res_df$PDbiasbonferroni.conflict <- as.factor(res_df$PDbiasbonferroni.conflict)
	res_df$PDbiasbonferroni.nonnat <- as.factor(res_df$PDbiasbonferroni.nonnat)
	res_df$PDbiasbonferroni.pollution <- as.factor(res_df$PDbiasbonferroni.pollution)
	res_df$PDbiasbonferroni.hybrid <- as.factor(res_df$PDbiasbonferroni.hybrid)
	res_df$PDbiasbonferroni.prey <- as.factor(res_df$PDbiasbonferroni.prey)
	res_df$PDbiasbonferroni.disease <- as.factor(res_df$PDbiasbonferroni.disease)
	res_df$PDbiasbonferroni.inbreeding <- as.factor(res_df$PDbiasbonferroni.inbreeding)
	res_df$FDbias.allthreats <- as.factor(res_df$FDbias.allthreats)
	res_df$FDbias.habitat <- as.factor(res_df$FDbias.habitat)
	res_df$FDbias.hunting <- as.factor(res_df$FDbias.hunting)
	res_df$FDbias.climate <- as.factor(res_df$FDbias.climate)
	res_df$FDbias.conflict <- as.factor(res_df$FDbias.conflict)
	res_df$FDbias.nonnat <- as.factor(res_df$FDbias.nonnat)
	res_df$FDbias.pollution <- as.factor(res_df$FDbias.pollution)
	res_df$FDbias.hybrid <- as.factor(res_df$FDbias.hybrid)
	res_df$FDbias.prey <- as.factor(res_df$FDbias.prey)
	res_df$FDbias.disease <- as.factor(res_df$FDbias.disease)
	res_df$FDbias.inbreeding <- as.factor(res_df$FDbias.inbreeding)
	res_df$PDbias.allthreats <- as.factor(res_df$PDbias.allthreats)
	res_df$PDbias.habitat <- as.factor(res_df$PDbias.habitat)
	res_df$PDbias.hunting <- as.factor(res_df$PDbias.hunting)
	res_df$PDbias.climate <- as.factor(res_df$PDbias.climate)
	res_df$PDbias.conflict <- as.factor(res_df$PDbias.conflict)
	res_df$PDbias.nonnat <- as.factor(res_df$PDbias.nonnat)
	res_df$PDbias.pollution <- as.factor(res_df$PDbias.pollution)
	res_df$PDbias.hybrid <- as.factor(res_df$PDbias.hybrid)
	res_df$PDbias.prey <- as.factor(res_df$PDbias.prey)
	res_df$PDbias.disease <- as.factor(res_df$PDbias.disease)
	res_df$PDbias.inbreeding <- as.factor(res_df$PDbias.inbreeding)

	res_sf <- res_df %>% 
		left_join(ctrs, by = "Country") %>%
		st_as_sf(sf_column_name = "geometry", crs = prj) %>%
		mutate(ctry_sq_km = as.numeric(st_area(.))/1000000)  

	

# =============================================================================
#  6-panel maps
# =============================================================================


#--- Prepping FD bias
biascolors <- c("-1" = "blue", "0" = "white", "1" = "red")	
FDbias_cols <- c(173, 174, 175, 177) # column numbers for FDbias, 4 threats
#FDbias_cols <- c(195, 196, 197, 199) # column numbers for FDbias, 4 threats, Bonferroni-correction
FDbias_sf <- res_sf[FDbias_cols]


#--- Prepping PD bias
biascolors <- c("-1" = "blue", "0" = "white", "1" = "red")	
PDbias_cols <- c(184, 185, 186, 188) # column numbers for PDbias, 4 threats
#PDbias_cols <- c(206, 207, 208, 210) # column numbers for PDbias, 4 threats, Bonferroni-correction
PDbias_sf <- res_sf[PDbias_cols]


#--- Prepping FD	
# Raw
func_plot_cols <- c(15, 16, 17, 18, 20) # column numbers for FD values
fd_res_sf <- res_sf[func_plot_cols]
colnames(fd_res_sf)[1] <- "current"

# Prep plotting data for raw value decline
raw_fd_decline_sf <- fd_res_sf %>%
	mutate_at(vars(FD.allthreats:FD.conflict),  ~(current - (current * .))) %>%
	dplyr::select(-current) 

# Prep plotting data for proportional decline
prop_fd_decline_sf <- fd_res_sf %>%
	mutate_at(vars(FD.allthreats:FD.conflict),  ~(ifelse(current == 0, 0, 1 - .))) %>%
	dplyr::select(-current)


#--- Prepping PD	
# Raw
phylo_plot_cols <- c(82, 83, 84, 85, 87) # column numbers for PD
pd_res_sf <- res_sf[phylo_plot_cols]
colnames(pd_res_sf)[1] <- "current"
	
# Prep plotting data for raw value decline
raw_pd_decline_sf <- pd_res_sf %>%
	mutate_at(vars(PD.allthreats:PD.conflict),  ~(current - (current * .))) %>%
	dplyr::select(-current) 

# Prep plotting data for proportional decline
prop_pd_decline_sf <- pd_res_sf %>%
	mutate_at(vars(PD.allthreats:PD.conflict),  ~(ifelse(current == 0, 0, 1 - .))) %>%
	dplyr::select(-current) 
	

#--- Loop
for(i in 1:4){	# loop through each threat
	#i=2

	#--- FD Bias
	FDbiascol_var <- colnames(FDbias_sf[i])[1]
	tmp_raw <- FDbias_sf %>%
		dplyr::select(FDbiascol_var)
	
	FDbiasplot <- ggplot() +
		geom_sf(data = FDbias_sf, 
			aes(colour = get(noquote(FDbiascol_var)),  
				fill = get(noquote(FDbiascol_var))), 
			size = 0.4) +
		theme(plot.background = element_blank(),
			legend.position = "none", 
			#legend.position = "right", 
			#legend.direction = "vertical",
			#legend.spacing.y = unit(0.25, 'cm'),
			#legend.title = element_text(size = 9),
			#legend.text = element_text(size = 8),
			panel.background = element_blank(), 
			panel.grid.major = element_line(colour = "transparent"),
			panel.grid.minor = element_line(colour = "transparent"),
			panel.border = element_blank()) + 
		scale_colour_manual(values = biascolors, breaks = c("-1", "0", "1")) +
		scale_fill_manual(values = biascolors, breaks = c("-1", "0", "1")) +
		geom_sf(data = con_out, fill = "transparent", color = "grey70") +
		coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) 	

	save_nam <- strsplit(FDbiascol_var, "_")[[1]][1]
	ggsave(paste("Results/SinglePanelGraphs/", save_nam, ".tiff", sep = ""), width = 10, height = 5, units = 'in', dpi = 300)


	#--- PD Bias
	PDbiascol_var <- colnames(PDbias_sf[i])[1]
	tmp_raw <- PDbias_sf %>%
		dplyr::select(PDbiascol_var)
	
	PDbiasplot <- ggplot() +
		geom_sf(data = PDbias_sf, 
			aes(colour = get(noquote(PDbiascol_var)),  
				fill = get(noquote(PDbiascol_var))), 
			size = 0.4) +
		theme(plot.background = element_blank(),
			legend.position = "none", 
			#legend.position = "right", 
			#legend.direction = "vertical",
			#legend.spacing.y = unit(0.25, 'cm'),
			#legend.title = element_text(size = 9),
			#legend.text = element_text(size = 8),
			panel.background = element_blank(), 
			panel.grid.major = element_line(colour = "transparent"),
			panel.grid.minor = element_line(colour = "transparent"),
			panel.border = element_blank()) + 
		scale_colour_manual(values = biascolors, breaks = c("-1", "0", "1")) +
		scale_fill_manual(values = biascolors, breaks = c("-1", "0", "1")) +
		geom_sf(data = con_out, fill = "transparent", color = "grey70") +
		coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) 	

	save_nam <- strsplit(PDbiascol_var, "_")[[1]][1]
	ggsave(paste("Results/SinglePanelGraphs/", save_nam, ".tiff", sep = ""), width = 10, height = 5, units = 'in', dpi = 300)


	#--- FD		
	FDcol_var_raw <- colnames(raw_fd_decline_sf[i])[1]
	FDcol_var_prop <- colnames(prop_fd_decline_sf[i])[1]
	tmp_prop <- prop_fd_decline_sf %>%
		dplyr::select(FDcol_var_prop)
	high_prop_fd_decline_sf <- tmp_prop %>%
		dplyr::filter_at(vars(-geometry), any_vars(. > 0.69999))
	rest_prop_fd_decline_sf <- tmp_prop %>%
		dplyr::filter_at(vars(-geometry), any_vars(. < 0.699991))
		
	FD_abs <- ggplot() +
		geom_sf(data = raw_fd_decline_sf, 
			aes(colour = get(noquote(FDcol_var_prop)),  
				fill = get(noquote(FDcol_var_prop))), 
			size = 0.4) +
		scale_colour_gradient(high = "red", 
			low ="white", 
			name = "Raw              \ndecline", 
			na.value = "transparent", 
			limits=c(0, 70), 
			guide = FALSE) +
		scale_fill_gradient(high = "red", 
			low ="white", 
			name = "Raw              \ndecline", 
			na.value = "transparent", 
			limits=c(0, 70),
			breaks = c(10, 30, 50, 70),
			labels = c("10", "30", "50", "70")) +
		guides(fill = guide_colorbar(ticks = FALSE)) +
		geom_sf(data = con_out, fill = "transparent", color = "grey70", size = 0.3) +
		coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) +
		theme(plot.background = element_blank(),
			#legend.title = element_text(family = "Calibri", size = 10, face="italic"),
			#legend.text = element_text(family = "Calibri", size = 9),
			#legend.background = element_rect(fill="white", colour = "black"),
			#legend.position = "right", 
			legend.position = "none",
			#legend.direction = "vertical",
			#legend.spacing.x = unit(0.5, 'cm'),
			#legend.spacing.y = unit(0.2, 'cm'),
			panel.background = element_blank(), 
			panel.grid.major = element_line(colour = "transparent"),
			panel.grid.minor = element_line(colour = "transparent"),
			panel.border = element_blank(), 
			plot.margin = unit(c(-4,-2,-4,-2), "lines"))
	
	save_nam <- strsplit(FDcol_var_raw, "_")[[1]][1]
	ggsave(paste("Results/SinglePanelGraphs/", save_nam, ".abs", ".tiff", sep = ""), width = 10, height = 5, units = 'in', dpi = 300)

	FD_prop <- ggplot() +
		geom_sf(data = rest_prop_fd_decline_sf, 
			aes(colour = get(noquote(FDcol_var_prop)),  
				fill = get(noquote(FDcol_var_prop))), 
			size = 0.4) +
		geom_sf(data = high_prop_fd_decline_sf, 
			colour = "red", 
			fill = "red") +
		scale_colour_gradient(high = "red", 
			low ="white", 
			name = "Proportional \ndecline", 
			na.value = "transparent", 
			limits=c(0, 0.7), 
			guide = FALSE) +
		scale_fill_gradient(high = "red", 
			low ="white", 
			name = "Proportional \ndecline", 
			na.value = "transparent", 
			limits=c(0, 0.7),
			breaks = c(0.1, 0.3, 0.5, 0.7),
			labels = c("0.1", "0.3", "0.5", "0.7+")) +
		guides(fill = guide_colorbar(ticks = FALSE)) +
		geom_sf(data = con_out, fill = "transparent", color = "grey60", size = 0.3) +
		coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) +
		theme(plot.background = element_blank(),
			#legend.title = element_text(family = "Calibri", size = 10, face="italic"),
			#legend.text = element_text(family = "Calibri", size = 9),
			#legend.background = element_rect(fill="white", colour = "black"),
			#legend.position = "right", 
			legend.position = "none",
			#legend.direction = "vertical",
			#legend.spacing.x = unit(0.5, 'cm'),
			#legend.spacing.y = unit(0.2, 'cm'),
			panel.background = element_blank(), 
			panel.grid.major = element_line(colour = "transparent"),
			panel.grid.minor = element_line(colour = "transparent"),
			panel.border = element_blank(),
			plot.margin = unit(c(-4,-2,-4,-2), "lines"))
		
	save_nam <- strsplit(FDcol_var_raw, "_")[[1]][1]
	ggsave(paste("Results/SinglePanelGraphs/", save_nam, ".prop", ".tiff", sep = ""), width = 10, height = 5, units = 'in', dpi = 300)


	#--- PD		
	PDcol_var_raw <- colnames(raw_pd_decline_sf[i])[1]
	PDcol_var_prop <- colnames(prop_pd_decline_sf[i])[1]
	tmp_prop <- prop_pd_decline_sf %>%
		dplyr::select(PDcol_var_prop)
	high_prop_pd_decline_sf <- tmp_prop %>%
		dplyr::filter_at(vars(-geometry), any_vars(. > 0.69999))
	rest_prop_pd_decline_sf <- tmp_prop %>%
		dplyr::filter_at(vars(-geometry), any_vars(. < 0.699991))
		

	PD_abs <- ggplot() +
		geom_sf(data = raw_pd_decline_sf, 
			aes(colour = get(noquote(PDcol_var_prop)),  
				fill = get(noquote(PDcol_var_prop))), 
			size = 0.4) +
		scale_colour_gradient(high = "red", 
			low ="white", 
			name = "Raw              \ndecline", 
			na.value = "transparent", 
			limits=c(0, 10), 
			guide = FALSE) +
		scale_fill_gradient(high = "red", 
			low ="white", 
			name = "Raw              \ndecline", 
			na.value = "transparent", 
			limits=c(0, 10),
			breaks = c(2, 4, 6, 8, 10),
			labels = c("2", "4", "6", "8", "10")) +
		guides(fill = guide_colorbar(ticks = FALSE)) +
		geom_sf(data = con_out, fill = "transparent", color = "grey70", size = 0.3) +
		coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) +
		theme(plot.background = element_blank(),
			#legend.title = element_text(family = "Calibri", size = 10, face="italic"),
			#legend.text = element_text(family = "Calibri", size = 9),
			#legend.background = element_rect(fill="white", colour = "black"),
			#legend.position = "right", 
			legend.position = "none", 
			#legend.direction = "vertical",
			#legend.spacing.x = unit(0.5, 'cm'),
			#legend.spacing.y = unit(0.2, 'cm'),
			panel.background = element_blank(), 
			panel.grid.major = element_line(colour = "transparent"),
			panel.grid.minor = element_line(colour = "transparent"),
			panel.border = element_blank(), 
			plot.margin = unit(c(-4,-2,-4,-2), "lines"))
		
	save_nam <- strsplit(PDcol_var_raw, "_")[[1]][1]
	ggsave(paste("Results/SinglePanelGraphs/", save_nam, ".abs", ".tiff", sep = ""), width = 10, height = 5, units = 'in', dpi = 300)


	PD_prop <- ggplot() +
		geom_sf(data = rest_prop_pd_decline_sf, 
			aes(colour = get(noquote(PDcol_var_prop)),  
				fill = get(noquote(PDcol_var_prop))), 
			size = 0.4) +
		geom_sf(data = high_prop_pd_decline_sf, 
			colour = "red", 
			fill = "red") +
		scale_colour_gradient(high = "red", 
			low ="white", 
			name = "Proportional \ndecline", 
			na.value = "transparent", 
			limits=c(0, 0.7), 
			guide = FALSE) +
		scale_fill_gradient(high = "red", 
			low ="white", 
			name = "Proportional \ndecline", 
			na.value = "transparent", 
			limits=c(0, 0.7),
			breaks = c(0.1, 0.3, 0.5, 0.7),
			labels = c("0.1", "0.3", "0.5", "0.7+")) +
		guides(fill = guide_colorbar(ticks = FALSE)) +
		geom_sf(data = con_out, fill = "transparent", color = "grey60", size = 0.3) +
		coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) +
		theme(plot.background = element_blank(),
			#legend.title = element_text(family = "Calibri", size = 10, face="italic"),
			#legend.text = element_text(family = "Calibri", size = 9),
			#legend.background = element_rect(fill="white", colour = "black"),
			#legend.position = "right", 
			legend.position = "none", 
			#legend.direction = "vertical",
			#legend.spacing.x = unit(0.5, 'cm'),
			#legend.spacing.y = unit(0.2, 'cm'),
			panel.background = element_blank(), 
			panel.grid.major = element_line(colour = "transparent"),
			panel.grid.minor = element_line(colour = "transparent"),
			panel.border = element_blank(),
			plot.margin = unit(c(-4,-2,-4,-2), "lines"))
		
	save_nam <- strsplit(PDcol_var_raw, "_")[[1]][1]
	ggsave(paste("Results/SinglePanelGraphs/", save_nam, ".prop", ".tiff", sep = ""), width = 10, height = 5, units = 'in', dpi = 300)


	#--- Assemble multi-panel plot
	save_nam <- strsplit(colnames(FDbias_sf[i])[1], ".", fixed = TRUE)[[1]][2]

	p <- cowplot::plot_grid(FD_abs, PD_abs, FD_prop, PD_prop, FDbiasplot, PDbiasplot, 
		align = "hv", labels = NULL, ncol = 2, nrow = 3)

	ggsave(paste("Results/MultiPanelMaps/", save_nam, ".tiff", sep = ""), width = 20, height = 15, units = 'in', dpi = 300)
	

}	# end i loop



















# =============================================================================
#  Faceted plots of SR.0, FD.0, and PD.0
# =============================================================================
	
	# ----------------------
	#  Baseline - current taxonomic, functional and phylogenetic diversity
	curr_plot_cols <- c(3, 15, 82) # column numbers for SR0, FD0, and PD0

	
	# ----------------------
	#  Prep plotting data 
	curr_res_sf <- res_sf[curr_plot_cols]
	
	td_mu <- mean(curr_res_sf$SR.0, na.rm = TRUE)
	td_sd <- sd(curr_res_sf$SR.0, na.rm = TRUE)
	fd_mu <- mean(curr_res_sf$FD.0, na.rm = TRUE)
	fd_sd <- sd(curr_res_sf$FD.0, na.rm = TRUE)
	pd_mu <- mean(curr_res_sf$PD.0, na.rm = TRUE)
	pd_sd <- sd(curr_res_sf$PD.0, na.rm = TRUE)
	
	colnames(curr_res_sf)[1:3] <- c("Current Taxonomic Diversity", 
		"Current Functional Diversity",
		"Current Phylogenetic Diversity")

	curr_res_sf_long <- curr_res_sf %>% gather(richness, value, -geometry) 

	td_tmp <- curr_res_sf_long %>%
		dplyr::filter(richness == "Current Taxonomic Diversity") %>%
		mutate(stand_val = (value - td_mu) / td_sd)

	fd_tmp <- curr_res_sf_long %>%
		dplyr::filter(richness == "Current Functional Diversity") %>%
		mutate(stand_val = (value - fd_mu) / fd_sd)

	pd_tmp <- curr_res_sf_long %>%
		dplyr::filter(richness == "Current Phylogenetic Diversity") %>%
		mutate(stand_val = (value - pd_mu) / pd_sd)

	curr_res_sf_long_stand <- td_tmp %>%
		rbind(fd_tmp) %>%
		rbind(pd_tmp)
		
		
	tiff("Results/MultiPanelMaps/current_div_facet.tiff", width = 6, height = 9, units = 'in', res = 300)


	#----- Faceted plot
	p_curr_div <- ggplot() +
		geom_sf(data = curr_res_sf_long_stand, aes(colour = stand_val, fill = stand_val)) +
		theme(plot.background = element_blank(),
			legend.position = "right", 
			legend.direction = "vertical",
			legend.spacing.y = unit(0.25, 'cm'),
			panel.background = element_blank(), 
			panel.grid.major = element_line(colour = "transparent"),
			panel.grid.minor = element_line(colour = "transparent"),
			panel.border = element_blank(),
			strip.placement = "outside", 
			strip.background = element_rect("transparent"),
			panel.spacing = unit(0.5, "cm"), 
			plot.title = element_blank(),
			legend.title = element_text(family = "Calibri", size = 10, face="italic"),
			legend.text = element_text(family = "Calibri", size = 9),
			strip.text = element_text(family = "Calibri", size = 10, margin = margin(0.1, 0, 0.1, 0, "cm")),
			legend.background = element_rect(fill="white", colour = "black")) +
		#geom_sf(data = con_out, fill = "transparent", color = "grey70", size = 0.4) +
		facet_wrap(vars(richness), ncol = 1, strip.position = "top") +
		scale_colour_gradient(high = "forestgreen", low ="white", 
			name = "Standardized \nrichness metric", na.value = "transparent") +
		scale_fill_gradient(high = "forestgreen", low ="white", 
			guide = FALSE, na.value = "black") +
		guides(colour = guide_colorbar(ticks = FALSE)) +
		coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs"))

	p_curr_div
	dev.off()

	
	#----- Test
		col_var_prop <- colnames(curr_res_sf_long_stand)[1]

		tmp <- ggplot() +
			geom_sf(data = curr_res_sf_long_stand, 
				aes(colour = get(noquote(col_var_prop)),  
					fill = get(noquote(col_var_prop))), 
				size = 0.4) +
			scale_colour_gradient(high = "red", 
				low ="white", 
				name = "Raw              \ndecline", 
				na.value = "transparent", 
				limits=c(0, 70), 
				guide = FALSE) +
			scale_fill_gradient(high = "red", 
				low ="white", 
				name = "Raw              \ndecline", 
				na.value = "transparent", 
				limits=c(0, 70),
				breaks = c(10, 30, 50, 70),
				labels = c("10", "30", "50", "70")) +
			guides(fill = guide_colorbar(ticks = FALSE)) +
			geom_sf(data = con_out, fill = "transparent", color = "grey70", size = 0.3) +
			coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) +
			theme(plot.background = element_blank(),
				legend.title = element_text(family = "Calibri", size = 10, face="italic"),
				legend.text = element_text(family = "Calibri", size = 9),
				legend.background = element_rect(fill="white", colour = "black"),
				legend.position = "right", 
				legend.direction = "vertical",
				legend.spacing.x = unit(0.5, 'cm'),
				legend.spacing.y = unit(0.2, 'cm'),
				panel.background = element_blank(), 
				panel.grid.major = element_line(colour = "transparent"),
				panel.grid.minor = element_line(colour = "transparent"),
				panel.border = element_blank(), 
				plot.margin = unit(c(3,3,3,3), "lines"))













	
# =============================================================================
#  Functional Diversity
# =============================================================================

	# ----------------------
	#  Raw
	func_plot_cols <- c(15, seq(16, 26, by = 1)) # column numbers for FD values
	fd_res_sf <- res_sf[func_plot_cols]
	colnames(fd_res_sf)[1] <- "current"
	
	# ----------------------
	#  Prep plotting data for raw value decline
	raw_fd_decline_sf <- fd_res_sf %>%
		mutate_at(vars(FD.allthreats:FD.inbreeding1),  ~(current - (current * .))) %>%
		dplyr::select(-current) 

	# ----------------------
	#  Prep plotting data for proportional decline
	prop_fd_decline_sf <- fd_res_sf %>%
		mutate_at(vars(FD.allthreats:FD.inbreeding1),  ~(ifelse(current == 0, 0, 1 - .))) %>%
		dplyr::select(-current) 

	
for(i in 1:11){	# loop through each threat

		#i=2
			
		# ----------------------
		#  Set up column that is used for raw value data
		col_var_raw <- colnames(raw_fd_decline_sf[i])[1]
		
		# ----------------------
		#  Set up column that is used for proportional data
		col_var_prop <- colnames(prop_fd_decline_sf[i])[1]
		
		# ----------------------
		#  Color scale ranges
		tmp_prop <- prop_fd_decline_sf %>%
			dplyr::select(col_var_prop)
		high_prop_fd_decline_sf <- tmp_prop %>%
			dplyr::filter_at(vars(-geometry), any_vars(. > 0.69999))
		rest_prop_fd_decline_sf <- tmp_prop %>%
			dplyr::filter_at(vars(-geometry), any_vars(. < 0.699991))
		
		
		# ----------------------
		#  Generate plots
		raw_FD <- ggplot() +
			geom_sf(data = raw_fd_decline_sf, 
				aes(colour = get(noquote(col_var_prop)),  
					fill = get(noquote(col_var_prop))), 
				size = 0.4) +
			scale_colour_gradient(high = "red", 
				low ="white", 
				name = "Raw              \ndecline", 
				na.value = "transparent", 
				limits=c(0, 70), 
				guide = FALSE) +
			scale_fill_gradient(high = "red", 
				low ="white", 
				name = "Raw              \ndecline", 
				na.value = "transparent", 
				limits=c(0, 70),
				breaks = c(10, 30, 50, 70),
				labels = c("10", "30", "50", "70")) +
			guides(fill = guide_colorbar(ticks = FALSE)) +
			geom_sf(data = con_out, fill = "transparent", color = "grey70", size = 0.3) +
			coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) +
			theme(plot.background = element_blank(),
				legend.title = element_text(family = "Calibri", size = 10, face="italic"),
				legend.text = element_text(family = "Calibri", size = 9),
				legend.background = element_rect(fill="white", colour = "black"),
				legend.position = "right", 
				legend.direction = "vertical",
				legend.spacing.x = unit(0.5, 'cm'),
				legend.spacing.y = unit(0.2, 'cm'),
				panel.background = element_blank(), 
				panel.grid.major = element_line(colour = "transparent"),
				panel.grid.minor = element_line(colour = "transparent"),
				panel.border = element_blank(), 
				plot.margin = unit(c(3,3,3,3), "lines"))
		
		
		prop_FD <- ggplot() +
			geom_sf(data = rest_prop_fd_decline_sf, 
				aes(colour = get(noquote(col_var_prop)),  
					fill = get(noquote(col_var_prop))), 
				size = 0.4) +
			geom_sf(data = high_prop_fd_decline_sf, 
				colour = "red", 
				fill = "red") +
			scale_colour_gradient(high = "red", 
				low ="white", 
				name = "Proportional \ndecline", 
				na.value = "transparent", 
				limits=c(0, 0.7), 
				guide = FALSE) +
			scale_fill_gradient(high = "red", 
				low ="white", 
				name = "Proportional \ndecline", 
				na.value = "transparent", 
				limits=c(0, 0.7),
				breaks = c(0.1, 0.3, 0.5, 0.7),
				labels = c("0.1", "0.3", "0.5", "0.7+")) +
			guides(fill = guide_colorbar(ticks = FALSE)) +
			geom_sf(data = con_out, fill = "transparent", color = "grey60", size = 0.3) +
			coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) +
			theme(plot.background = element_blank(),
				legend.title = element_text(family = "Calibri", size = 10, face="italic"),
				legend.text = element_text(family = "Calibri", size = 9),
				legend.background = element_rect(fill="white", colour = "black"),
				legend.position = "right", 
				legend.direction = "vertical",
				legend.spacing.x = unit(0.5, 'cm'),
				legend.spacing.y = unit(0.2, 'cm'),
				panel.background = element_blank(), 
				panel.grid.major = element_line(colour = "transparent"),
				panel.grid.minor = element_line(colour = "transparent"),
				panel.border = element_blank(),
				plot.margin = unit(c(3,3,3,3), "lines"))
			
		
		threat <- strsplit(col_var_raw, "_")[[1]][1]
		save_nam <- paste(threat, "_prop_raw", sep = "")


		# ----------------------
		#  Draw plots
		p <- plot_grid(raw_FD, prop_FD, labels = "AUTO", ncol = 1, nrow = 2, label_size = 11)
		ggsave(paste(save_nam, ".tiff", sep = ""), width = 9, height = 9, units = 'in', dpi = 300)
		
}	# end i loop



	
# =============================================================================
#  Phylogenetic Diversity
# =============================================================================
	
	# ----------------------
	#  Raw
	phylo_plot_cols <- seq(82, 93, by = 1) # column numbers for PD
	pd_res_sf <- res_sf[phylo_plot_cols]
	colnames(pd_res_sf)[1] <- "current"
	
	# ----------------------
	#  Prep plotting data for raw value decline
	raw_pd_decline_sf <- pd_res_sf %>%
		mutate_at(vars(PD.allthreats:PD.inbreeding1),  ~(current - (current * .))) %>%
		dplyr::select(-current) 

	# ----------------------
	#  Prep plotting data for proportional decline
	prop_pd_decline_sf <- pd_res_sf %>%
		mutate_at(vars(PD.allthreats:PD.inbreeding1),  ~(ifelse(current == 0, 0, 1 - .))) %>%
		dplyr::select(-current) 
	
	
for(i in 1:11){	# loop through each threat
		
		# ----------------------
		#  Set up column that is used for raw value data
		col_var_raw <- colnames(raw_pd_decline_sf[i])[1]
		
		# ----------------------
		#  Set up column that is used for proportional data
		col_var_prop <- colnames(prop_pd_decline_sf[i])[1]
		
		# ----------------------
		#  Color scale ranges
		tmp_prop <- prop_pd_decline_sf %>%
			dplyr::select(col_var_prop)
		high_prop_pd_decline_sf <- tmp_prop %>%
			dplyr::filter_at(vars(-geometry), any_vars(. > 0.69999))
		rest_prop_pd_decline_sf <- tmp_prop %>%
			dplyr::filter_at(vars(-geometry), any_vars(. < 0.699991))
		
		
		# ----------------------
		#  Generate plots
		raw_PD <- ggplot() +
			geom_sf(data = raw_pd_decline_sf, 
				aes(colour = get(noquote(col_var_prop)),  
					fill = get(noquote(col_var_prop))), 
				size = 0.4) +
			scale_colour_gradient(high = "red", 
				low ="white", 
				name = "Raw              \ndecline", 
				na.value = "transparent", 
				limits=c(0, 10), 
				guide = FALSE) +
			scale_fill_gradient(high = "red", 
				low ="white", 
				name = "Raw              \ndecline", 
				na.value = "transparent", 
				limits=c(0, 10),
				breaks = c(2, 4, 6, 8, 10),
				labels = c("2", "4", "6", "8", "10")) +
			guides(fill = guide_colorbar(ticks = FALSE)) +
			geom_sf(data = con_out, fill = "transparent", color = "grey70", size = 0.3) +
			coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) +
			theme(plot.background = element_blank(),
				legend.title = element_text(family = "Calibri", size = 10, face="italic"),
				legend.text = element_text(family = "Calibri", size = 9),
				legend.background = element_rect(fill="white", colour = "black"),
				legend.position = "right", 
				legend.direction = "vertical",
				legend.spacing.x = unit(0.5, 'cm'),
				legend.spacing.y = unit(0.2, 'cm'),
				panel.background = element_blank(), 
				panel.grid.major = element_line(colour = "transparent"),
				panel.grid.minor = element_line(colour = "transparent"),
				panel.border = element_blank(), 
				plot.margin = unit(c(3,3,3,3), "lines"))
		
		
		prop_PD <- ggplot() +
			geom_sf(data = rest_prop_pd_decline_sf, 
				aes(colour = get(noquote(col_var_prop)),  
					fill = get(noquote(col_var_prop))), 
				size = 0.4) +
			geom_sf(data = high_prop_pd_decline_sf, 
				colour = "red", 
				fill = "red") +
			scale_colour_gradient(high = "red", 
				low ="white", 
				name = "Proportional \ndecline", 
				na.value = "transparent", 
				limits=c(0, 0.7), 
				guide = FALSE) +
			scale_fill_gradient(high = "red", 
				low ="white", 
				name = "Proportional \ndecline", 
				na.value = "transparent", 
				limits=c(0, 0.7),
				breaks = c(0.1, 0.3, 0.5, 0.7),
				labels = c("0.1", "0.3", "0.5", "0.7+")) +
			guides(fill = guide_colorbar(ticks = FALSE)) +
			geom_sf(data = con_out, fill = "transparent", color = "grey60", size = 0.3) +
			coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) +
			theme(plot.background = element_blank(),
				legend.title = element_text(family = "Calibri", size = 10, face="italic"),
				legend.text = element_text(family = "Calibri", size = 9),
				legend.background = element_rect(fill="white", colour = "black"),
				legend.position = "right", 
				legend.direction = "vertical",
				legend.spacing.x = unit(0.5, 'cm'),
				legend.spacing.y = unit(0.2, 'cm'),
				panel.background = element_blank(), 
				panel.grid.major = element_line(colour = "transparent"),
				panel.grid.minor = element_line(colour = "transparent"),
				panel.border = element_blank(),
				plot.margin = unit(c(3,3,3,3), "lines"))
			
		
		threat <- strsplit(col_var_raw, "_")[[1]][1]
		save_nam <- paste(threat, "_prop_raw", sep = "")


		# ----------------------
		#  Draw plots
		p <- plot_grid(raw_PD, prop_PD, labels = "AUTO", ncol = 1, nrow = 2, label_size = 11)
		ggsave(paste(save_nam, ".tiff", sep = ""), width = 9, height = 9, units = 'in', dpi = 300)
		
}	# end i loop

	
	
# =============================================================================
#  Taxonomic Diversity
# =============================================================================
	
	# ----------------------
	#  Raw
	taxo_plot_cols <- c(seq(3, 14, by = 1)) # column numbers for SR
	td_res_sf <- res_sf[taxo_plot_cols]
	colnames(td_res_sf)[1] <- "current"
	
	# ----------------------
	#  Prep plotting data for raw value decline
	raw_td_decline_sf <- td_res_sf %>%
		mutate_at(vars(SR.allthreats:SR.inbreeding1),  ~(current - .)) %>%
		dplyr::select(-current) 

	# ----------------------
	#  Prep plotting data for proportional decline
	prop_td_decline_sf <- td_res_sf %>%
		mutate_at(vars(SR.allthreats:SR.inbreeding1),  ~(ifelse(current == 0, 0, (current - .) / current))) %>%
		dplyr::select(-current) 

	
	for(i in 1:11){
		
		#i=1		

		# ----------------------
		#  Set up column that is used for raw value data
		col_var_raw <- colnames(raw_td_decline_sf[i])[1]
		
		# ----------------------
		#  Set up column that is used for proportional data
		col_var_prop <- colnames(prop_td_decline_sf[i])[1]
		
		# ----------------------
		#  Color scale ranges
		tmp_prop <- prop_td_decline_sf %>%
			dplyr::select(col_var_prop)
		high_prop_td_decline_sf <- tmp_prop %>%
			dplyr::filter_at(vars(-geometry), any_vars(. > 0.69999))
		rest_prop_td_decline_sf <- tmp_prop %>%
			dplyr::filter_at(vars(-geometry), any_vars(. < 0.699991))
		
		# ----------------------
		#  Generate plots
		raw_TD <- ggplot() +
			geom_sf(data = raw_td_decline_sf, 
				aes(colour = get(noquote(col_var_prop)),  
					fill = get(noquote(col_var_prop))), 
				size = 0.4) +
			scale_colour_gradient(high = "red", 
				low ="white", 
				name = "Raw              \ndecline", 
				na.value = "transparent", 
				limits=c(0, 240), 
				guide = FALSE) +
			scale_fill_gradient(high = "red", 
				low ="white", 
				name = "Raw              \ndecline", 
				na.value = "transparent", 
				limits=c(0, 240),
				breaks = c(60, 120, 180, 240),
				labels = c("60", "120", "180", "240")) +
			guides(fill = guide_colorbar(ticks = FALSE)) +
			geom_sf(data = con_out, fill = "transparent", color = "grey70", size = 0.3) +
			coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) +
			theme(plot.background = element_blank(),
				legend.title = element_text(family = "Calibri", size = 10, face="italic"),
				legend.text = element_text(family = "Calibri", size = 9),
				legend.background = element_rect(fill="white", colour = "black"),
				legend.position = "right", 
				legend.direction = "vertical",
				legend.spacing.x = unit(0.5, 'cm'),
				legend.spacing.y = unit(0.2, 'cm'),
				panel.background = element_blank(), 
				panel.grid.major = element_line(colour = "transparent"),
				panel.grid.minor = element_line(colour = "transparent"),
				panel.border = element_blank(), 
				plot.margin = unit(c(3,3,3,3), "lines"))
		
		
		prop_TD <- ggplot() +
			geom_sf(data = rest_prop_td_decline_sf, 
				aes(colour = get(noquote(col_var_prop)),  
					fill = get(noquote(col_var_prop))), 
				size = 0.4) +
			geom_sf(data = high_prop_td_decline_sf, 
				colour = "red", 
				fill = "red") +
			scale_colour_gradient(high = "red", 
				low ="white", 
				name = "Proportional \ndecline", 
				na.value = "transparent", 
				limits=c(0, 0.7), 
				guide = FALSE) +
			scale_fill_gradient(high = "red", 
				low ="white", 
				name = "Proportional \ndecline", 
				na.value = "transparent", 
				limits=c(0, 0.7),
				breaks = c(0.1, 0.3, 0.5, 0.7),
				labels = c("0.1", "0.3", "0.5", "0.7+")) +
			guides(fill = guide_colorbar(ticks = FALSE)) +
			geom_sf(data = con_out, fill = "transparent", color = "grey60", size = 0.3) +
			coord_sf(crs = st_crs("+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")) +
			theme(plot.background = element_blank(),
				legend.title = element_text(family = "Calibri", size = 10, face="italic"),
				legend.text = element_text(family = "Calibri", size = 9),
				legend.background = element_rect(fill="white", colour = "black"),
				legend.position = "right", 
				legend.direction = "vertical",
				legend.spacing.x = unit(0.5, 'cm'),
				legend.spacing.y = unit(0.2, 'cm'),
				panel.background = element_blank(), 
				panel.grid.major = element_line(colour = "transparent"),
				panel.grid.minor = element_line(colour = "transparent"),
				panel.border = element_blank(),
				plot.margin = unit(c(3,3,3,3), "lines"))
			
		
		threat <- strsplit(col_var_raw, "_")[[1]][1]
		save_nam <- paste(threat, "_prop_raw", sep = "")


		# ----------------------
		#  Draw plots
		p <- plot_grid(raw_TD, prop_TD, labels = "AUTO", ncol = 1, nrow = 2, label_size = 11)
		ggsave(paste(save_nam, ".tiff", sep = ""), width = 9, height = 9, units = 'in', dpi = 300)
		
		}


	
	
	
	
	














