


library(dplyr)
library(sf)
library(sp)
library(spdep)







############## DATA FROM FD & PD ANALYSIS ###################################################
rm(list = ls())
dat00 <- data.frame(read.csv("Results/FuncPhylo_mammals200421.csv", header=T))

# Subset data to only include countries with enough species for robust FD estimates
dat0 <- subset(dat00, SR.0 > 4)






############## SET SOME PARAMETERS ###################################################
spdep::set.ZeroPolicyOption(TRUE)

# Set the 'neighborhood radius' for the spatial autogressive models
nbrad <- 1000000 # 1000 km






############## SPATIAL DATA FOR EACH COUNTRY ###################################################
# projection in m instead of lat/long
prj <- "+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs"
	

# country polygons
countries_latlong <- st_read("Data/Raw/UIA_World_Countries_Boundaries.shp") %>%
	dplyr::select(Country, geometry) 
countries_m <- st_transform(countries_latlong, crs = st_crs(prj))


# country centroids
centroids <- st_centroid(countries_m)
centroids <- st_transform(centroids, crs = st_crs("+proj=longlat +datum=WGS84 +no_defs"))
countrylist <- as.data.frame(centroids$Country)
coords <- st_coordinates(centroids)
centroids <- cbind.data.frame(countrylist, coords)
names(centroids) <- c("Country", "long", "lat")






############## MODELS ######################################################################
dat1 <- left_join(dat0, centroids, by = "Country")
dat1$lat <- abs(dat1$lat)


# Spaital data for models
p <- dat1 %>%
	left_join(countries_m, by = "Country") %>%
	dplyr::select(Country, geometry) %>%
	st_as_sf(sf_column_name = "geometry") %>%
	mutate(Id = 1:n())

# Centroids for spatial autocorrelation covariate
xy <- st_coordinates(st_centroid(st_geometry(p), of_largest_polygon=TRUE))




#----- FD. Habitat.-----------------------------------------------
y <- dat1$FDbias.habitat
y[y < 0] <- 0


# Initial glm models
m1 <- glm(y ~ dat1$SR.0, family = "binomial")
summary(m1)


# Attach model residuals to country data
p$value <- residuals(m1)


# Test for spatial autocorrelation
w <- spdep::poly2nb(p, row.names = p$Id)
ww <-  spdep::nb2listw(w, style = "B", zero.policy=TRUE)
print(ww, zero.policy = TRUE)
moran(p$value, ww, n = length(ww$neighbours), S0 = Szero(ww))
moran.mc(p$value, ww, nsim = 999)
# p-value = 0.001, greater correlation than expected by chance


# Generate spatial autocorrelation covariate to include in glm()
ac <- autocov_dist(y, xy, nbs = nbrad, style="B", type = "one")


# Spatially autoregressive glm models
m1_ar <- glm(y ~ dat1$SR.0 + ac, family = "binomial")
summary(m1_ar)

m2 <- glm(y ~ dat1$SR.0 + dat1$lat + ac + dat1$SR.0:dat1$lat, family = "binomial")
summary(m2)


# Predictions
newdat <- cbind.data.frame(SR.0 = dat1$SR.0, ac = mean(ac))
newdat$pred <- data.frame(predict(m1_ar, newdata = newdat, type = "response", se.fit = T))$fit
newdat$pred.se <- data.frame(predict(m1_ar, newdata = newdat, type = "response", se.fit = T))$se.fit
write.csv(newdat, "Results/predict_spatialGLM_FD_habitat.csv", row.names = F)




#----- FD. Hunting.-----------------------------------------------
y <- dat1$FDbias.hunting
y[y < 0] <- 0


# Initial glm models
m1 <- glm(y ~ dat1$SR.0, family = "binomial")
summary(m1)


# Attach model residuals to country data
p$value <- residuals(m1)


# Test for spatial autocorrelation
w <- spdep::poly2nb(p, row.names = p$Id)
ww <-  spdep::nb2listw(w, style = "B", zero.policy=TRUE)
print(ww, zero.policy = TRUE)
moran(p$value, ww, n = length(ww$neighbours), S0 = Szero(ww))
moran.mc(p$value, ww, nsim = 999)
# p-value = 0.001, greater correlation than expected by chance


# Generate spatial autocorrelation covariate to include in glm()
ac <- autocov_dist(y, xy, nbs = nbrad, style="B", type = "one")


# Spatially autoregressive glm models
m1_ar <- glm(y ~ dat1$SR.0 + ac, family = "binomial")
summary(m1_ar)

m2 <- glm(y ~ dat1$SR.0 + dat1$lat + ac + dat1$SR.0:dat1$lat, family = "binomial")
summary(m2)


# Predictions
newdat <- cbind.data.frame(SR.0 = dat1$SR.0, ac = mean(ac))
newdat$pred <- data.frame(predict(m1_ar, newdata = newdat, type = "response", se.fit = T))$fit
newdat$pred.se <- data.frame(predict(m1_ar, newdata = newdat, type = "response", se.fit = T))$se.fit
write.csv(newdat, "Results/predict_spatialGLM_FD_hunting.csv", row.names = F)




#----- PD. Habitat.-----------------------------------------------
y <- dat1$PDbias.habitat
y[y < 0] <- 0


# Initial glm models
m1 <- glm(y ~ dat1$SR.0, family = "binomial")
summary(m1)


# Attach model residuals to country data
p$value <- residuals(m1)


# Test for spatial autocorrelation
w <- spdep::poly2nb(p, row.names = p$Id)
ww <-  spdep::nb2listw(w, style = "B", zero.policy=TRUE)
print(ww, zero.policy = TRUE)
moran(p$value, ww, n = length(ww$neighbours), S0 = Szero(ww))
moran.mc(p$value, ww, nsim = 999)
# p-value = 0.058, *not* greater correlation than expected by chance


# Generate spatial autocorrelation covariate to include in glm()
ac <- autocov_dist(y, xy, nbs = nbrad, style="B", type = "one")


# Spatially autoregressive glm models
m1_ar <- glm(y ~ dat1$SR.0 + ac, family = "binomial")
summary(m1_ar)
# AIC is worse than that of m1

m2 <- glm(y ~ dat1$SR.0 + dat1$lat + ac + dat1$SR.0:dat1$lat, family = "binomial")
summary(m2)




#----- PD. Hunting.-----------------------------------------------
y <- dat1$PDbias.hunting
y[y < 0] <- 0


# Initial glm models
m1 <- glm(y ~ dat1$SR.0, family = "binomial")
summary(m1)


# Attach model residuals to country data
p$value <- residuals(m1)


# Test for spatial autocorrelation
w <- spdep::poly2nb(p, row.names = p$Id)
ww <-  spdep::nb2listw(w, style = "B", zero.policy=TRUE)
print(ww, zero.policy = TRUE)
moran(p$value, ww, n = length(ww$neighbours), S0 = Szero(ww))
moran.mc(p$value, ww, nsim = 999)
# p-value = 0.013, greater correlation than expected by chance


# Generate spatial autocorrelation covariate to include in glm()
ac <- autocov_dist(y, xy, nbs = nbrad, style="B", type = "one")


# Spatially autoregressive glm models
m1_ar <- glm(y ~ dat1$SR.0 + ac, family = "binomial")
summary(m1_ar)

m2 <- glm(y ~ dat1$SR.0 + dat1$lat + ac + dat1$SR.0:dat1$lat, family = "binomial")
summary(m2)




#----- Inference ------------------------------------------------------------------
# For FD.habitat, FD.hunting, and PD.hunting, the probability of species loss being biased is greater
# in high-diversity nations. Latitude has no effect. 




#--------- Moran's I interpretation -----------------------------------------------
# Null hypothesis states that the attribute being analyzed is randomly distributed among the features 
# in your study area (the spatial processes promoting the observed pattern of values is random chance).
# When the p-value returned by this tool is statistically significant, you can reject the null hypothesis.

# Significant p-vaue and positive Z-score:
# The spatial distribution of high values and/or low values in the dataset is more spatially clustered than 
# would be expected if underlying spatial processes were random.

# Significant p-vaue and negative Z-score:
# he spatial distribution of high values and low values in the dataset is more spatially dispersed than would 
# be expected if underlying spatial processes were random












