


library(dplyr)
library(picante)
library(funrar)
library(rr2)




############################ DATA ################################################################
# Load data
rm(list = ls())
dat0 <- data.frame(read.csv("Data/Raw/mammal_threats_traits.csv", header = T))
spptree <- read.tree("Data/Upham_mean_phylogeny_ultrametric.tree")


# Housekeeping
dat0$species <- as.character(dat0$species)
dat0$habitat[dat0$habitat > 1] <- 0
dat0$hunting[dat0$hunting > 1] <- 0


# Evolutionary distinctiveness
tmp <- picante::evol.distinct(spptree, type = "equal.splits", scale = FALSE, use.branch.lengths = TRUE)
names(tmp) <- c("species.phylog", "EvolDistinct")
dat1 <- left_join(dat0, tmp, by = "species.phylog")


# Functional distinctiveness
Traits <- subset(dat0, select = -c(rowID, species, species.phylog, family, order, trend, ExceptionsToDecline,
	habitat, hunting, conflict, climate, NonNatives, pollution, hybrid, prey, disease, inbreeding))
row.names(Traits) <- dat0$species
TraitDistMat <- funrar::compute_dist_matrix(Traits, metric = "euclidean", center = T, scale = T)
GlobalMammals <- matrix(1, ncol = nrow(dat0))
colnames(GlobalMammals) <- dat0$species
row.names(GlobalMammals) <- c("GlobalMammals")
tmp1 <- t(funrar::distinctiveness(GlobalMammals, TraitDistMat))
dat1$FuncDistinct <- as.numeric(tmp1)


# Standardize the distinctiveness variables
m1 <- mean(dat1$EvolDistinct, na.rm = T)
sd1 <- sd(dat1$EvolDistinct, na.rm = T)
dat1$EvolDistinct <- (dat1$EvolDistinct - m1) / sd1
m2 <- mean(dat1$FuncDistinct, na.rm = T)
sd2 <- sd(dat1$FuncDistinct, na.rm = T)
dat1$FuncDistinct <- (dat1$FuncDistinct - m2) / sd2




############################ SUBSET THE DATA ################################################################
dat <- dat1[complete.cases(dat1), ]
dat <- subset(dat, select = -c(rowID, species))
names(dat)[names(dat) == "species.phylog"] <- "species"


# Remove duplicated species
tmp <- data.frame(duplicated(dat$species))
names(tmp) <- "logical"
tmp$duplicate <- ifelse(tmp$logical == TRUE, 1, 0)
dat$duplicate <- tmp$duplicate
dat <- subset(dat, duplicate == 0)


# Identify species in phylogeny that are not in the threats/traits database
SppInData <- data.frame(dat$species)
SppInPhylog <- data.frame(spptree$tip.label)
names(SppInData) <- "species"
names(SppInPhylog) <- "species"
SppToRemove <- anti_join(SppInPhylog, SppInData, by = "species")


# Remove those species
spptree1 <- spptree
for(i in 1:nrow(SppToRemove)){
	spptree1 <- drop.tip(spptree1, tip = SppToRemove[i,1])	}




############################ PHYLOGENETIC MODELS ################################################################
row.names(dat) <- dat$species


# habitat loss
start <- Sys.time()
start
mod1 <- rr2::binaryPGLMM(habitat ~ EvolDistinct + FuncDistinct, data = dat, phy = spptree1)
Sys.time() - start # 19 hours on laptop
mod1
summary(mod1)
rr2::R2(mod1)


# hunting
start <- Sys.time()
start
mod2 <- rr2::binaryPGLMM(hunting ~ EvolDistinct + FuncDistinct, data = dat, phy = spptree1)
Sys.time() - start # 19 hours on laptop
mod2
summary(mod2)
rr2::R2(mod2)

























############################ OTHER PHYLOGENETIC MODELS (NOT CURRENTLY USED) #############################
modMP1 <- phylolm::phyloglm(habitat ~ EvolDistinct, data = dat, phy = spptree1, method = "logistic_MPLE")

modBM <- nlme::gls(Fruit_lg ~ SundaPalawan + Sulawesi + Moluccas + New_Guinea, 
	correlation=corBrownian(1, phy=tempTree), data=dat, method="ML")

modOU <- nlme::gls(Fruit_lg ~ SundaPalawan + Sulawesi + Moluccas + New_Guinea, 
	correlation=corMartins(1, phy=tempTree), data=dat, method="ML")



