

library(dplyr)
library(ape)
library(phytools)
library(picante)
library(funrar)
library(rr2)
library(tidyr)
library(sf)
library(raster)
library(phyr)
library(lme4)





############################ USER-DEFINED PARAMETERS #####################################
rm(list = ls())

# Load functions
source("0_FunctionalDiversity190528_funs.R")
st_erase = function(x, y) st_difference(x, st_union(st_combine(y)))

# Desired patial projection
prj <- "+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs"
	





############################ DATA ################################################################
# Load data
dat0 <- data.frame(read.csv("Data/Raw/mammal_threats_traits.csv", header = T))
spptree <- read.tree("Data/Upham_mean_phylogeny_ultrametric.tree")


# Housekeeping
dat0$species <- as.character(dat0$species)
dat0$species.phylog <- as.character(dat0$species.phylog)
dat0$habitat[dat0$habitat > 1] <- 0
dat0$hunting[dat0$hunting > 1] <- 0


# Evolutionary distinctiveness
tmp <- picante::evol.distinct(spptree, type = "equal.splits", scale = FALSE, use.branch.lengths = TRUE)
names(tmp) <- c("species.phylog", "EvolDistinct")
dat1 <- left_join(dat0, tmp, by = "species.phylog")


# Functional distinctiveness
Traits <- subset(dat0, select = -c(rowID, species, species.phylog, family, order, trend, ExceptionsToDecline,
	habitat, hunting, conflict, climate, NonNatives, pollution, hybrid, prey, disease, inbreeding))
row.names(Traits) <- dat0$species
TraitDistMat <- funrar::compute_dist_matrix(Traits, metric = "euclidean", center = T, scale = T)
GlobalMammals <- matrix(1, ncol = nrow(dat0))
colnames(GlobalMammals) <- dat0$species
row.names(GlobalMammals) <- c("GlobalMammals")
tmp1 <- t(funrar::distinctiveness(GlobalMammals, TraitDistMat))
dat1$FuncDistinct <- as.numeric(tmp1)


# Standardize the distinctiveness variables
m1 <- mean(dat1$EvolDistinct, na.rm = T)
sd1 <- sd(dat1$EvolDistinct, na.rm = T)
dat1$EvolDistinct <- (dat1$EvolDistinct - m1) / sd1
m2 <- mean(dat1$FuncDistinct, na.rm = T)
sd2 <- sd(dat1$FuncDistinct, na.rm = T)
dat1$FuncDistinct <- (dat1$FuncDistinct - m2) / sd2
	





############################ COUNTRIES AND SPP RANGE PREP ############################
ctrs <- st_read("Data/Raw/UIA_World_Countries_Boundaries.shp") %>%
	dplyr::select(Country, geometry) %>%
	st_transform(st_crs(prj)) %>%
	mutate(ctry_sq_km = as.numeric(st_area(.))/1000000)  
ctrs_area <- ctrs %>%
	as.data.frame() %>%
	dplyr::select(Country, ctry_sq_km, - geometry) 
ctrs_df <- ctrs %>%	
	as.data.frame() %>%
	dplyr::select(-geometry) 
ctrs_df$Country <- as.character(ctrs_df$Country)

# Run functions to prepare range polygons
# removes mammals who are listed as extinct
mam <- prep_range_polys(fn = "Data/Raw/TERRESTRIAL_MAMMALS.shp", ctrs = ctrs)


# Species-country intersections 
polys_ctrs_int <- st_intersects(mam, ctrs, sparse = FALSE) 
# Dimensions: nrow = number of spp (12112 for mammals), ncol = number of countries (254)

spp_int_ls <- list()
for(i in 1:nrow(ctrs_df)){
	polys_ctrs_int_vec <- which(polys_ctrs_int[,i] == TRUE)
	spp_list_ctr <- mam[polys_ctrs_int_vec, 1]
	st_geometry(spp_list_ctr) <- NULL
	spp_int_ls[[i]] <- spp_list_ctr	}


# Manually add species present in IUCN range descriptions but not IUCN range maps
# Maldives
add <- data.frame(species = "Myotis_blythii")
spp_int_ls[[59]] <- rbind(spp_int_ls[[59]], add)
# Turkey
add <- data.frame(species = "Miniopterus_schreibersii")
spp_int_ls[[16]] <- rbind(spp_int_ls[[16]], add)
# France
add <- data.frame(species = "Speothos_venaticus")
spp_int_ls[[34]] <- rbind(spp_int_ls[[34]], add)
# Sri Lanka
add <- data.frame(species = "Myotis_blythii")
spp_int_ls[[63]] <- rbind(spp_int_ls[[63]], add)
# Bangladesh
add <- data.frame(species = "Myotis_blythii")
spp_int_ls[[80]] <- rbind(spp_int_ls[[80]], add)
# Bhutan
add <- data.frame(species = "Myotis_blythii")
spp_int_ls[[81]] <- rbind(spp_int_ls[[81]], add)
# Israel
add <- data.frame(species = "Gazella_dorcas")
spp_int_ls[[224]] <- rbind(spp_int_ls[[224]], add)
# Croatia
add <- data.frame(species = "Miniopterus_schreibersii")
spp_int_ls[[248]] <- rbind(spp_int_ls[[248]], add)
# Bulgaria
add <- data.frame(species = "Miniopterus_schreibersii")
spp_int_ls[[254]] <- rbind(spp_int_ls[[254]], add)


# Exceptions to decline
exc_tmp <- dat1 %>%
	dplyr::select(species, ExceptionsToDecline)
exc_tmp$ExceptionsToDecline <- as.character(exc_tmp$ExceptionsToDecline)

#  Do first one to start data frame
spp <- exc_tmp$species[1]
tmp <- exc_tmp$ExceptionsToDecline[1]
tmp_df <- as.data.frame(tmp) %>%
	tidyr::separate(tmp, paste("Country", 1:22, sep="_"), sep = ", ") 
exc_df <- cbind(spp, tmp_df)

for(i in 1:nrow(exc_tmp)){
	spp <- exc_tmp$species[i]
	tmp <- exc_tmp$ExceptionsToDecline[i]
	tmp_df <- as.data.frame(tmp) %>%
		tidyr::separate(tmp, paste("Country", 1:22, sep="_"), sep = ", ") 
	new_row <- cbind(spp, tmp_df)
	exc_df <- rbind(exc_df, new_row)	}
	
exc_df <- exc_df[rowSums(is.na(exc_df[,2:23])) != 22,]
exc_df <- exc_df %>%
	mutate_if(is.factor, as.character)

dat1 <- subset(dat1, select = -c(ExceptionsToDecline))

numcountries <- length(spp_int_ls)


# Loop through each country
datout <- dat1[1,]
datout$country <- NA
datout <- datout[-1,]

for(i in 1:nrow(ctrs_df)){ 
	#i=7
	country_name <- as.character(ctrs_df[i,1])
	keep_exc <- which(apply(exc_df, 1, function(r) any(r %in% country_name)))
	spp_exc <- exc_df[keep_exc,1]
	spp_exc_df <- as.data.frame(spp_exc)
	colnames(spp_exc_df) <- "species"
	spp_list <- spp_int_ls[[i]]
	spp_list <- unique(spp_list) 
	tmp <- dplyr::left_join(spp_list, dat1, by = "species")	
	if(nrow(tmp)>0){tmp$country <- country_name}
	datout <- rbind.data.frame(datout, tmp)
	rm(country_name, keep_exc, spp_exc, spp_exc_df, spp_list, tmp)	}


# Remove countries with <4 species
countries <- ctrs_df
for(i in 1:nrow(countries)){
	#i=3
	country_name <- as.character(ctrs_df[i,1])
	keep_exc <- which(apply(exc_df, 1, function(r) any(r %in% country_name)))
	spp_exc <- exc_df[keep_exc,1]
	spp_exc_df <- as.data.frame(spp_exc)
	colnames(spp_exc_df) <- "species"
	spp_list <- spp_int_ls[[i]]
	countries$numspp[i] <- nrow(unique(spp_list))	}
countries.to.remove <- subset(countries, numspp < 4)

for(i in 1:nrow(countries.to.remove)){
	#i=1
	datout <- subset(datout, country != countries.to.remove$Country[i])	}
datout <- subset(datout, country != "Vatican City")
	





############################ DATABASE & PHYLOGENY ################################################################
dat <- datout[complete.cases(datout), ]
dat <- subset(dat, select = -c(species, rowID))
#write.csv(dat, file = "temp_dat.csv", row.names = F)
#dat <- read.csv("temp_dat.csv", header = T)
phy <- spptree
dat$sp <- dat$species.phylog
dat$site <- dat$country
	





############################ PHYR MODELS ################################################################

# Habitat-simple
dat1 <- dat
dat1$y <- ifelse(dat1$trend == "Decreasing" & dat1$habitat == 1, 1, 0)
start <- Sys.time()
start
mod <- phyr::pglmm(y ~ DietVert + DietFruit + DietSeed + DietHerb + BodyMass + EvolDistinct + (1|sp__) + (1|site),
	data = dat1, family = "binomial", cov_ranef = list(sp = phy), verbose = F, bayes = TRUE, calc.DIC = TRUE)
save(mod, file = "mod_hab_simple.Rdata")
#rm(mod)
Sys.time() - start # ~14 hours on the laptop



# Hunting-simple
dat1 <- dat
dat1$y <- ifelse(dat1$trend == "Decreasing" & dat1$hunting == 1, 1, 0)
start <- Sys.time()
start
mod <- phyr::pglmm(y ~ DietVert + DietFruit + DietSeed + DietHerb + BodyMass + EvolDistinct + (1|sp__) + (1|site),
	data = dat1, family = "binomial", cov_ranef = list(sp = phy), verbose = F, bayes = TRUE, calc.DIC = TRUE)
save(mod, file = "mod_hunt_simple.Rdata")
rm(mod)
Sys.time() - start


































